Class: Google::Cloud::NetworkConnectivity::V1beta::GatewayAdvertisedRoute

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb

Overview

A gateway advertised route is a route that a gateway spoke advertises somewhere.

Defined Under Namespace

Modules: Recipient Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the gateway advertised route was created.

Returns:



1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1533

class GatewayAdvertisedRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The recipient of an advertised route.
  module Recipient
    # No recipient specified. By default routes are advertised to the hub.
    RECIPIENT_UNSPECIFIED = 0

    # Advertises a route toward the hub. Other spokes reachable from this spoke
    # will receive the route.
    ADVERTISE_TO_HUB = 1
  end
end

#description::String

Returns An optional description of the gateway advertised route.

Returns:

  • (::String)

    An optional description of the gateway advertised route.



1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1533

class GatewayAdvertisedRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The recipient of an advertised route.
  module Recipient
    # No recipient specified. By default routes are advertised to the hub.
    RECIPIENT_UNSPECIFIED = 0

    # Advertises a route toward the hub. Other spokes reachable from this spoke
    # will receive the route.
    ADVERTISE_TO_HUB = 1
  end
end

#ip_range::String

Returns Immutable. This route's advertised IP address range. Must be a valid CIDR-formatted prefix. If an IP address is provided without a subnet mask, it is interpreted as, for IPv4, a /32 singular IP address range, and, for IPv6, /128.

Returns:

  • (::String)

    Immutable. This route's advertised IP address range. Must be a valid CIDR-formatted prefix. If an IP address is provided without a subnet mask, it is interpreted as, for IPv4, a /32 singular IP address range, and, for IPv6, /128.



1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1533

class GatewayAdvertisedRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The recipient of an advertised route.
  module Recipient
    # No recipient specified. By default routes are advertised to the hub.
    RECIPIENT_UNSPECIFIED = 0

    # Advertises a route toward the hub. Other spokes reachable from this spoke
    # will receive the route.
    ADVERTISE_TO_HUB = 1
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional labels in key-value pair format. For more information about labels, see Requirements for labels.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional labels in key-value pair format. For more information about labels, see Requirements for labels.



1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1533

class GatewayAdvertisedRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The recipient of an advertised route.
  module Recipient
    # No recipient specified. By default routes are advertised to the hub.
    RECIPIENT_UNSPECIFIED = 0

    # Advertises a route toward the hub. Other spokes reachable from this spoke
    # will receive the route.
    ADVERTISE_TO_HUB = 1
  end
end

#name::String

Returns Identifier. The name of the gateway advertised route. Route names must be unique and use the following form: projects/{project_number}/locations/{region}/spokes/{spoke}/gatewayAdvertisedRoutes/{gateway_advertised_route_id}.

Returns:

  • (::String)

    Identifier. The name of the gateway advertised route. Route names must be unique and use the following form: projects/{project_number}/locations/{region}/spokes/{spoke}/gatewayAdvertisedRoutes/{gateway_advertised_route_id}



1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1533

class GatewayAdvertisedRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The recipient of an advertised route.
  module Recipient
    # No recipient specified. By default routes are advertised to the hub.
    RECIPIENT_UNSPECIFIED = 0

    # Advertises a route toward the hub. Other spokes reachable from this spoke
    # will receive the route.
    ADVERTISE_TO_HUB = 1
  end
end

#priority::Integer

Returns Optional. The priority of this advertised route. You can choose a value from 0 to 65335. If you don't provide a value, Google Cloud assigns a priority of 100 to the ranges.

Returns:

  • (::Integer)

    Optional. The priority of this advertised route. You can choose a value from 0 to 65335. If you don't provide a value, Google Cloud assigns a priority of 100 to the ranges.



1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1533

class GatewayAdvertisedRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The recipient of an advertised route.
  module Recipient
    # No recipient specified. By default routes are advertised to the hub.
    RECIPIENT_UNSPECIFIED = 0

    # Advertises a route toward the hub. Other spokes reachable from this spoke
    # will receive the route.
    ADVERTISE_TO_HUB = 1
  end
end

#recipient::Google::Cloud::NetworkConnectivity::V1beta::GatewayAdvertisedRoute::Recipient

Returns Optional. The recipient of this advertised route.

Returns:



1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1533

class GatewayAdvertisedRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The recipient of an advertised route.
  module Recipient
    # No recipient specified. By default routes are advertised to the hub.
    RECIPIENT_UNSPECIFIED = 0

    # Advertises a route toward the hub. Other spokes reachable from this spoke
    # will receive the route.
    ADVERTISE_TO_HUB = 1
  end
end

#state::Google::Cloud::NetworkConnectivity::V1beta::State (readonly)

Returns Output only. The current lifecycle state of this gateway advertised route.

Returns:



1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1533

class GatewayAdvertisedRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The recipient of an advertised route.
  module Recipient
    # No recipient specified. By default routes are advertised to the hub.
    RECIPIENT_UNSPECIFIED = 0

    # Advertises a route toward the hub. Other spokes reachable from this spoke
    # will receive the route.
    ADVERTISE_TO_HUB = 1
  end
end

#unique_id::String (readonly)

Returns Output only. The Google-generated UUID for the gateway advertised route. This value is unique across all gateway advertised route resources. If a gateway advertised route is deleted and another with the same name is created, the new route is assigned a different unique_id.

Returns:

  • (::String)

    Output only. The Google-generated UUID for the gateway advertised route. This value is unique across all gateway advertised route resources. If a gateway advertised route is deleted and another with the same name is created, the new route is assigned a different unique_id.



1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1533

class GatewayAdvertisedRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The recipient of an advertised route.
  module Recipient
    # No recipient specified. By default routes are advertised to the hub.
    RECIPIENT_UNSPECIFIED = 0

    # Advertises a route toward the hub. Other spokes reachable from this spoke
    # will receive the route.
    ADVERTISE_TO_HUB = 1
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the gateway advertised route was last updated.

Returns:



1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1533

class GatewayAdvertisedRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The recipient of an advertised route.
  module Recipient
    # No recipient specified. By default routes are advertised to the hub.
    RECIPIENT_UNSPECIFIED = 0

    # Advertises a route toward the hub. Other spokes reachable from this spoke
    # will receive the route.
    ADVERTISE_TO_HUB = 1
  end
end