Class: Google::Cloud::NetworkConnectivity::V1beta::GetGatewayAdvertisedRouteRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the gateway advertised route to get.

Returns:

  • (::String)

    Required. The name of the gateway advertised route to get.



1536
1537
1538
1539
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1536

class GetGatewayAdvertisedRouteRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end