Class: Google::Cloud::NetworkConnectivity::V1beta::GetStatusRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb

Overview

Message for getting a Transport's operational status.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. Name of the resource.

Returns:

  • (::String)

    Required. Name of the resource.



500
501
502
503
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 500

class GetStatusRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#skip_cache::Boolean

Returns Optional. If set to true, the response will bypass any caches and return the freshest possible data.

Returns:

  • (::Boolean)

    Optional. If set to true, the response will bypass any caches and return the freshest possible data.



500
501
502
503
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 500

class GetStatusRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end