Class: Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb

Overview

Message for the response to getting a Transport's operational status.

Defined Under Namespace

Modules: ConnectivityStatus, MacSecStatus, OperationalStatus, OverallStatus

Instance Attribute Summary collapse

Instance Attribute Details

#connectivity_status::Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse::ConnectivityStatus

Returns Current status of connectivity to the local GCP resource. This reflects whether the VPC Peering or NCC Hub appears correctly configured.

Returns:



523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 523

class GetStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The overall status of the Transport.
  module OverallStatus
    # Unspecified status.
    OVERALL_STATUS_UNSPECIFIED = 0

    # Resource is active and operational.
    ACTIVE = 1

    # Resource is waiting for an activation key to be exchanged.
    PENDING_KEY = 2

    # Activation keys have been exchanged and connectivity is being
    # established.
    CONFIGURING = 3

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    DISCONNECTED = 4

    # User configuration is correct, but the configured capacity is
    # operationally down.
    DOWN = 5
  end

  # The operational status of the underlying networking components.
  module OperationalStatus
    # Unspecified status.
    OPERATIONAL_STATUS_UNSPECIFIED = 0

    # Protected capacity is available and networking components show as up.
    OPERATIONAL_STATUS_ACTIVE = 1

    # Protected capacity is showing as operationally down.
    OPERATIONAL_STATUS_DOWN = 2
  end

  # Current status of connectivity to the local GCP resource. This reflects
  # whether the VPC Peering or NCC Hub appears correctly configured.
  module ConnectivityStatus
    # Unspecified status.
    CONNECTIVITY_STATUS_UNSPECIFIED = 0

    # VPC Peering or the NCC Hub appear to be correctly established.
    CONNECTIVITY_STATUS_CONNECTED = 1

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    CONNECTIVITY_STATUS_DISCONNECTED = 2
  end

  # Current status of MACSec on the underlying network connectivity between GC
  # and the partner.
  module MacSecStatus
    # Unspecified status.
    MAC_SEC_STATUS_UNSPECIFIED = 0

    # MACSec is protecting the links and configured in fail closed.
    MAC_SEC_STATUS_ACTIVE_FAIL_CLOSED = 1

    # MACSec is protecting the links and configured to fail open on at least
    # one of the redundant links.
    MAC_SEC_STATUS_ACTIVE_FAIL_OPEN = 2

    # MACSec is not configured on at least one of the underlying links.
    MAC_SEC_STATUS_NOT_CONFIGURED = 3
  end
end

#mac_sec_status::Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse::MacSecStatus

Returns Current status of MACSec on the underlying network connectivity between GC and the partner.

Returns:



523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 523

class GetStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The overall status of the Transport.
  module OverallStatus
    # Unspecified status.
    OVERALL_STATUS_UNSPECIFIED = 0

    # Resource is active and operational.
    ACTIVE = 1

    # Resource is waiting for an activation key to be exchanged.
    PENDING_KEY = 2

    # Activation keys have been exchanged and connectivity is being
    # established.
    CONFIGURING = 3

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    DISCONNECTED = 4

    # User configuration is correct, but the configured capacity is
    # operationally down.
    DOWN = 5
  end

  # The operational status of the underlying networking components.
  module OperationalStatus
    # Unspecified status.
    OPERATIONAL_STATUS_UNSPECIFIED = 0

    # Protected capacity is available and networking components show as up.
    OPERATIONAL_STATUS_ACTIVE = 1

    # Protected capacity is showing as operationally down.
    OPERATIONAL_STATUS_DOWN = 2
  end

  # Current status of connectivity to the local GCP resource. This reflects
  # whether the VPC Peering or NCC Hub appears correctly configured.
  module ConnectivityStatus
    # Unspecified status.
    CONNECTIVITY_STATUS_UNSPECIFIED = 0

    # VPC Peering or the NCC Hub appear to be correctly established.
    CONNECTIVITY_STATUS_CONNECTED = 1

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    CONNECTIVITY_STATUS_DISCONNECTED = 2
  end

  # Current status of MACSec on the underlying network connectivity between GC
  # and the partner.
  module MacSecStatus
    # Unspecified status.
    MAC_SEC_STATUS_UNSPECIFIED = 0

    # MACSec is protecting the links and configured in fail closed.
    MAC_SEC_STATUS_ACTIVE_FAIL_CLOSED = 1

    # MACSec is protecting the links and configured to fail open on at least
    # one of the redundant links.
    MAC_SEC_STATUS_ACTIVE_FAIL_OPEN = 2

    # MACSec is not configured on at least one of the underlying links.
    MAC_SEC_STATUS_NOT_CONFIGURED = 3
  end
end

#operational_status::Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse::OperationalStatus

Returns The operational status of the underlying networking components.

Returns:



523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 523

class GetStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The overall status of the Transport.
  module OverallStatus
    # Unspecified status.
    OVERALL_STATUS_UNSPECIFIED = 0

    # Resource is active and operational.
    ACTIVE = 1

    # Resource is waiting for an activation key to be exchanged.
    PENDING_KEY = 2

    # Activation keys have been exchanged and connectivity is being
    # established.
    CONFIGURING = 3

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    DISCONNECTED = 4

    # User configuration is correct, but the configured capacity is
    # operationally down.
    DOWN = 5
  end

  # The operational status of the underlying networking components.
  module OperationalStatus
    # Unspecified status.
    OPERATIONAL_STATUS_UNSPECIFIED = 0

    # Protected capacity is available and networking components show as up.
    OPERATIONAL_STATUS_ACTIVE = 1

    # Protected capacity is showing as operationally down.
    OPERATIONAL_STATUS_DOWN = 2
  end

  # Current status of connectivity to the local GCP resource. This reflects
  # whether the VPC Peering or NCC Hub appears correctly configured.
  module ConnectivityStatus
    # Unspecified status.
    CONNECTIVITY_STATUS_UNSPECIFIED = 0

    # VPC Peering or the NCC Hub appear to be correctly established.
    CONNECTIVITY_STATUS_CONNECTED = 1

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    CONNECTIVITY_STATUS_DISCONNECTED = 2
  end

  # Current status of MACSec on the underlying network connectivity between GC
  # and the partner.
  module MacSecStatus
    # Unspecified status.
    MAC_SEC_STATUS_UNSPECIFIED = 0

    # MACSec is protecting the links and configured in fail closed.
    MAC_SEC_STATUS_ACTIVE_FAIL_CLOSED = 1

    # MACSec is protecting the links and configured to fail open on at least
    # one of the redundant links.
    MAC_SEC_STATUS_ACTIVE_FAIL_OPEN = 2

    # MACSec is not configured on at least one of the underlying links.
    MAC_SEC_STATUS_NOT_CONFIGURED = 3
  end
end

#overall_status::Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse::OverallStatus

Returns The overall status of the Transport. This field will always output the most critical status of the Transport. For example, if the connectivity is DISCONNECTED, and the underlying networking components are DOWN, then the overall status will be DOWN.

Returns:



523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 523

class GetStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The overall status of the Transport.
  module OverallStatus
    # Unspecified status.
    OVERALL_STATUS_UNSPECIFIED = 0

    # Resource is active and operational.
    ACTIVE = 1

    # Resource is waiting for an activation key to be exchanged.
    PENDING_KEY = 2

    # Activation keys have been exchanged and connectivity is being
    # established.
    CONFIGURING = 3

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    DISCONNECTED = 4

    # User configuration is correct, but the configured capacity is
    # operationally down.
    DOWN = 5
  end

  # The operational status of the underlying networking components.
  module OperationalStatus
    # Unspecified status.
    OPERATIONAL_STATUS_UNSPECIFIED = 0

    # Protected capacity is available and networking components show as up.
    OPERATIONAL_STATUS_ACTIVE = 1

    # Protected capacity is showing as operationally down.
    OPERATIONAL_STATUS_DOWN = 2
  end

  # Current status of connectivity to the local GCP resource. This reflects
  # whether the VPC Peering or NCC Hub appears correctly configured.
  module ConnectivityStatus
    # Unspecified status.
    CONNECTIVITY_STATUS_UNSPECIFIED = 0

    # VPC Peering or the NCC Hub appear to be correctly established.
    CONNECTIVITY_STATUS_CONNECTED = 1

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    CONNECTIVITY_STATUS_DISCONNECTED = 2
  end

  # Current status of MACSec on the underlying network connectivity between GC
  # and the partner.
  module MacSecStatus
    # Unspecified status.
    MAC_SEC_STATUS_UNSPECIFIED = 0

    # MACSec is protecting the links and configured in fail closed.
    MAC_SEC_STATUS_ACTIVE_FAIL_CLOSED = 1

    # MACSec is protecting the links and configured to fail open on at least
    # one of the redundant links.
    MAC_SEC_STATUS_ACTIVE_FAIL_OPEN = 2

    # MACSec is not configured on at least one of the underlying links.
    MAC_SEC_STATUS_NOT_CONFIGURED = 3
  end
end