Module: Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse::OverallStatus

Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb

Overview

The overall status of the Transport.

Constant Summary collapse

OVERALL_STATUS_UNSPECIFIED =

Unspecified status.

0
ACTIVE =

Resource is active and operational.

1
PENDING_KEY =

Resource is waiting for an activation key to be exchanged.

2
CONFIGURING =

Activation keys have been exchanged and connectivity is being established.

3
DISCONNECTED =

VPC Peering has been taken down, or the NCC Spoke has been rejected.

4
DOWN =

User configuration is correct, but the configured capacity is operationally down.

5