Class: Google::Cloud::NetworkConnectivity::V1beta::Hub

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb

Overview

A Network Connectivity Center hub is a global management resource to which you attach spokes. A single hub can contain spokes from multiple regions. However, if any of a hub's spokes use the site-to-site data transfer feature, the resources associated with those spokes must all be in the same VPC network. Spokes that do not use site-to-site data transfer can be associated with any VPC network in your project.

Defined Under Namespace

Classes: ExportPscConfig, LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the hub was created.

Returns:



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns Optional. An optional description of the hub.

Returns:

  • (::String)

    Optional. An optional description of the hub.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#export_psc::Boolean

Returns Optional. Whether Private Service Connect connection propagation is enabled for the hub. If true, Private Service Connect endpoints in VPC spokes attached to the hub are made accessible to other VPC spokes attached to the hub. The default value is false.

Returns:

  • (::Boolean)

    Optional. Whether Private Service Connect connection propagation is enabled for the hub. If true, Private Service Connect endpoints in VPC spokes attached to the hub are made accessible to other VPC spokes attached to the hub. The default value is false.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#export_psc_config::Google::Cloud::NetworkConnectivity::V1beta::Hub::ExportPscConfig

Returns Optional. Config for more granular control of Private Service Connect transitivity.

Returns:



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional labels in key-value pair format. For more information about labels, see Requirements for labels.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional labels in key-value pair format. For more information about labels, see Requirements for labels.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Immutable. The name of the hub. Hub names must be unique. They use the following form: projects/{project_number}/locations/global/hubs/{hub_id}.

Returns:

  • (::String)

    Immutable. The name of the hub. Hub names must be unique. They use the following form: projects/{project_number}/locations/global/hubs/{hub_id}



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#policy_mode::Google::Cloud::NetworkConnectivity::V1beta::PolicyMode

Returns Optional. The policy mode of this hub. This field can be either PRESET or CUSTOM. If unspecified, the policy_mode defaults to PRESET.

Returns:



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#preset_topology::Google::Cloud::NetworkConnectivity::V1beta::PresetTopology

Returns Optional. The topology implemented in this hub. Currently, this field is only used when policy_mode = PRESET. The available preset topologies are MESH and STAR. If preset_topology is unspecified and policy_mode = PRESET, the preset_topology defaults to MESH. When policy_mode = CUSTOM, the preset_topology is set to PRESET_TOPOLOGY_UNSPECIFIED.

Returns:

  • (::Google::Cloud::NetworkConnectivity::V1beta::PresetTopology)

    Optional. The topology implemented in this hub. Currently, this field is only used when policy_mode = PRESET. The available preset topologies are MESH and STAR. If preset_topology is unspecified and policy_mode = PRESET, the preset_topology defaults to MESH. When policy_mode = CUSTOM, the preset_topology is set to PRESET_TOPOLOGY_UNSPECIFIED.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#route_tables::Array<::String> (readonly)

Returns Output only. The route tables that belong to this hub. They use the following form: projects/{project_number}/locations/global/hubs/{hub_id}/routeTables/{route_table_id}

This field is read-only. Network Connectivity Center automatically populates it based on the route tables nested under the hub.

Returns:

  • (::Array<::String>)

    Output only. The route tables that belong to this hub. They use the following form: projects/{project_number}/locations/global/hubs/{hub_id}/routeTables/{route_table_id}

    This field is read-only. Network Connectivity Center automatically populates it based on the route tables nested under the hub.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#routing_vpcs::Array<::Google::Cloud::NetworkConnectivity::V1beta::RoutingVPC> (readonly)

Returns Output only. The VPC networks associated with this hub's spokes.

This field is read-only. Network Connectivity Center automatically populates it based on the set of spokes attached to the hub.

Returns:



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#spoke_summary::Google::Cloud::NetworkConnectivity::V1beta::SpokeSummary (readonly)

Returns Output only. A summary of the spokes associated with a hub. The summary includes a count of spokes according to type and according to state. If any spokes are inactive, the summary also lists the reasons they are inactive, including a count for each reason.

Returns:

  • (::Google::Cloud::NetworkConnectivity::V1beta::SpokeSummary)

    Output only. A summary of the spokes associated with a hub. The summary includes a count of spokes according to type and according to state. If any spokes are inactive, the summary also lists the reasons they are inactive, including a count for each reason.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#state::Google::Cloud::NetworkConnectivity::V1beta::State (readonly)

Returns Output only. The current lifecycle state of this hub.

Returns:



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unique_id::String (readonly)

Returns Output only. The Google-generated UUID for the hub. This value is unique across all hub resources. If a hub is deleted and another with the same name is created, the new hub is assigned a different unique_id.

Returns:

  • (::String)

    Output only. The Google-generated UUID for the hub. This value is unique across all hub resources. If a hub is deleted and another with the same name is created, the new hub is assigned a different unique_id.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the hub was last updated.

Returns:



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 100

class Hub
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for more granular control of Private Service Connect
  # connection propagation.
  # This allows enabling or disabling connection propagation for specific types
  # of Private Service Connect endpoints.
  # @!attribute [rw] published_services_and_regional_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for regional
  #     ILBs and regional Google APIs should be propagated. Default value is true
  #     if export_psc is true. Otherwise, the default value is false.
  # @!attribute [rw] global_google_apis
  #   @return [::Boolean]
  #     Optional. Controls whether Private Service Connect endpoints for global
  #     Google APIs should be propagated. The default value is false.
  class ExportPscConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end