Class: Google::Cloud::NetworkConnectivity::V1beta::LinkedRouterApplianceInstances

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb

Overview

A collection of router appliance instances. If you configure multiple router appliance instances to receive data from the same set of sites outside of Google Cloud, we recommend that you associate those instances with the same spoke.

Instance Attribute Summary collapse

Instance Attribute Details

#exclude_export_ranges::Array<::String>

Returns Optional. Dynamic routes overlapped/encompassed by exclude export ranges are excluded during export to hub.

Returns:

  • (::Array<::String>)

    Optional. Dynamic routes overlapped/encompassed by exclude export ranges are excluded during export to hub.



1400
1401
1402
1403
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1400

class LinkedRouterApplianceInstances
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#exclude_import_ranges::Array<::String>

Returns Optional. Hub routes overlapped/encompassed by exclude import ranges are excluded during import from hub.

Returns:

  • (::Array<::String>)

    Optional. Hub routes overlapped/encompassed by exclude import ranges are excluded during import from hub.



1400
1401
1402
1403
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1400

class LinkedRouterApplianceInstances
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#include_export_ranges::Array<::String>

Returns Optional. Dynamic routes fully encompassed by include export ranges are included during export to hub.

Returns:

  • (::Array<::String>)

    Optional. Dynamic routes fully encompassed by include export ranges are included during export to hub.



1400
1401
1402
1403
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1400

class LinkedRouterApplianceInstances
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#include_import_ranges::Array<::String>

Returns Optional. Hub routes fully encompassed by include import ranges are included during import from hub.

Returns:

  • (::Array<::String>)

    Optional. Hub routes fully encompassed by include import ranges are included during import from hub.



1400
1401
1402
1403
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1400

class LinkedRouterApplianceInstances
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instances::Array<::Google::Cloud::NetworkConnectivity::V1beta::RouterApplianceInstance>

Returns The list of router appliance instances.

Returns:



1400
1401
1402
1403
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1400

class LinkedRouterApplianceInstances
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#site_to_site_data_transfer::Boolean

Returns A value that controls whether site-to-site data transfer is enabled for these resources. Data transfer is available only in supported locations.

Returns:

  • (::Boolean)

    A value that controls whether site-to-site data transfer is enabled for these resources. Data transfer is available only in supported locations.



1400
1401
1402
1403
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1400

class LinkedRouterApplianceInstances
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vpc_network::String (readonly)

Returns Output only. The VPC network where these router appliance instances are located.

Returns:

  • (::String)

    Output only. The VPC network where these router appliance instances are located.



1400
1401
1402
1403
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1400

class LinkedRouterApplianceInstances
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end