Class: Google::Cloud::NetworkConnectivity::V1beta::ListGatewayAdvertisedRoutesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::ListGatewayAdvertisedRoutesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
Response for HubService.ListGatewayAdvertisedRoutes method.
Instance Attribute Summary collapse
-
#gateway_advertised_routes ⇒ ::Array<::Google::Cloud::NetworkConnectivity::V1beta::GatewayAdvertisedRoute>
The requested gateway advertised routes.
-
#next_page_token ⇒ ::String
The token for the next page of the response.
-
#unreachable ⇒ ::Array<::String>
Hubs that could not be reached.
Instance Attribute Details
#gateway_advertised_routes ⇒ ::Array<::Google::Cloud::NetworkConnectivity::V1beta::GatewayAdvertisedRoute>
Returns The requested gateway advertised routes.
1583 1584 1585 1586 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1583 class ListGatewayAdvertisedRoutesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns The token for the next page of the response. To see more results, use this value as the page_token for your next request. If this value is empty, there are no more results.
1583 1584 1585 1586 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1583 class ListGatewayAdvertisedRoutesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Hubs that could not be reached.
1583 1584 1585 1586 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1583 class ListGatewayAdvertisedRoutesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |