Class: Google::Cloud::NetworkConnectivity::V1beta::ListHubSpokesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb

Overview

The request for HubService.ListHubSpokes.

Defined Under Namespace

Modules: SpokeView

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns An expression that filters the list of results.

Returns:

  • (::String)

    An expression that filters the list of results.



652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 652

class ListHubSpokesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that controls which spoke fields are included in the response.
  module SpokeView
    # The spoke view is unspecified. When the spoke view is unspecified, the
    # API returns the same fields as the `BASIC` view.
    SPOKE_VIEW_UNSPECIFIED = 0

    # Includes `name`, `create_time`, `hub`, `unique_id`, `state`, `reasons`,
    # and `spoke_type`. This is the default value.
    BASIC = 1

    # Includes all spoke fields except `labels`.
    # You can use the `DETAILED` view only when you set the `spoke_locations`
    # field to `[global]`.
    DETAILED = 2
  end
end

#name::String

Returns Required. The name of the hub.

Returns:

  • (::String)

    Required. The name of the hub.



652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 652

class ListHubSpokesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that controls which spoke fields are included in the response.
  module SpokeView
    # The spoke view is unspecified. When the spoke view is unspecified, the
    # API returns the same fields as the `BASIC` view.
    SPOKE_VIEW_UNSPECIFIED = 0

    # Includes `name`, `create_time`, `hub`, `unique_id`, `state`, `reasons`,
    # and `spoke_type`. This is the default value.
    BASIC = 1

    # Includes all spoke fields except `labels`.
    # You can use the `DETAILED` view only when you set the `spoke_locations`
    # field to `[global]`.
    DETAILED = 2
  end
end

#order_by::String

Returns Sort the results by name or create_time.

Returns:

  • (::String)

    Sort the results by name or create_time.



652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 652

class ListHubSpokesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that controls which spoke fields are included in the response.
  module SpokeView
    # The spoke view is unspecified. When the spoke view is unspecified, the
    # API returns the same fields as the `BASIC` view.
    SPOKE_VIEW_UNSPECIFIED = 0

    # Includes `name`, `create_time`, `hub`, `unique_id`, `state`, `reasons`,
    # and `spoke_type`. This is the default value.
    BASIC = 1

    # Includes all spoke fields except `labels`.
    # You can use the `DETAILED` view only when you set the `spoke_locations`
    # field to `[global]`.
    DETAILED = 2
  end
end

#page_size::Integer

Returns The maximum number of results to return per page.

Returns:

  • (::Integer)

    The maximum number of results to return per page.



652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 652

class ListHubSpokesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that controls which spoke fields are included in the response.
  module SpokeView
    # The spoke view is unspecified. When the spoke view is unspecified, the
    # API returns the same fields as the `BASIC` view.
    SPOKE_VIEW_UNSPECIFIED = 0

    # Includes `name`, `create_time`, `hub`, `unique_id`, `state`, `reasons`,
    # and `spoke_type`. This is the default value.
    BASIC = 1

    # Includes all spoke fields except `labels`.
    # You can use the `DETAILED` view only when you set the `spoke_locations`
    # field to `[global]`.
    DETAILED = 2
  end
end

#page_token::String

Returns The page token.

Returns:

  • (::String)

    The page token.



652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 652

class ListHubSpokesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that controls which spoke fields are included in the response.
  module SpokeView
    # The spoke view is unspecified. When the spoke view is unspecified, the
    # API returns the same fields as the `BASIC` view.
    SPOKE_VIEW_UNSPECIFIED = 0

    # Includes `name`, `create_time`, `hub`, `unique_id`, `state`, `reasons`,
    # and `spoke_type`. This is the default value.
    BASIC = 1

    # Includes all spoke fields except `labels`.
    # You can use the `DETAILED` view only when you set the `spoke_locations`
    # field to `[global]`.
    DETAILED = 2
  end
end

#spoke_locations::Array<::String>

Returns A list of locations. Specify one of the following: [global], a single region (for example, [us-central1]), or a combination of values (for example, [global, us-central1, us-west1]). If the spoke_locations field is populated, the list of results includes only spokes in the specified location. If the spoke_locations field is not populated, the list of results includes spokes in all locations.

Returns:

  • (::Array<::String>)

    A list of locations. Specify one of the following: [global], a single region (for example, [us-central1]), or a combination of values (for example, [global, us-central1, us-west1]). If the spoke_locations field is populated, the list of results includes only spokes in the specified location. If the spoke_locations field is not populated, the list of results includes spokes in all locations.



652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 652

class ListHubSpokesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that controls which spoke fields are included in the response.
  module SpokeView
    # The spoke view is unspecified. When the spoke view is unspecified, the
    # API returns the same fields as the `BASIC` view.
    SPOKE_VIEW_UNSPECIFIED = 0

    # Includes `name`, `create_time`, `hub`, `unique_id`, `state`, `reasons`,
    # and `spoke_type`. This is the default value.
    BASIC = 1

    # Includes all spoke fields except `labels`.
    # You can use the `DETAILED` view only when you set the `spoke_locations`
    # field to `[global]`.
    DETAILED = 2
  end
end

#view::Google::Cloud::NetworkConnectivity::V1beta::ListHubSpokesRequest::SpokeView

Returns The view of the spoke to return. The view that you use determines which spoke fields are included in the response.

Returns:



652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 652

class ListHubSpokesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that controls which spoke fields are included in the response.
  module SpokeView
    # The spoke view is unspecified. When the spoke view is unspecified, the
    # API returns the same fields as the `BASIC` view.
    SPOKE_VIEW_UNSPECIFIED = 0

    # Includes `name`, `create_time`, `hub`, `unique_id`, `state`, `reasons`,
    # and `spoke_type`. This is the default value.
    BASIC = 1

    # Includes all spoke fields except `labels`.
    # You can use the `DETAILED` view only when you set the `spoke_locations`
    # field to `[global]`.
    DETAILED = 2
  end
end