Class: Google::Cloud::NetworkConnectivity::V1beta::RejectSpokeUpdateRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::RejectSpokeUpdateRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
The request for HubService.RejectSpokeUpdate.
Instance Attribute Summary collapse
-
#details ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
-
#spoke_etag ⇒ ::String
Required.
-
#spoke_uri ⇒ ::String
Required.
Instance Attribute Details
#details ⇒ ::String
Returns Optional. Additional information provided by the hub administrator.
1113 1114 1115 1116 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1113 class RejectSpokeUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the hub to reject spoke update.
1113 1114 1115 1116 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1113 class RejectSpokeUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that a request doesn't result in creation of duplicate commitments for at least 60 minutes.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check to see whether the original operation was received. If it was, the server ignores the second request. This behavior prevents clients from mistakenly creating duplicate commitments.
The request ID must be a valid UUID, with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
1113 1114 1115 1116 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1113 class RejectSpokeUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#spoke_etag ⇒ ::String
Returns Required. The etag of the spoke to reject update.
1113 1114 1115 1116 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1113 class RejectSpokeUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#spoke_uri ⇒ ::String
Returns Required. The URI of the spoke to reject update.
1113 1114 1115 1116 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1113 class RejectSpokeUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |