Class: Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb

Overview

Message describing RemoteTransportProfile object.

Defined Under Namespace

Modules: Bandwidth, KeyProvisioningFlow, ServiceLevelAvailability, State Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#description::String (readonly)

Returns Output only. Description of the profile.

Returns:

  • (::String)

    Output only. Description of the profile.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 62

class RemoteTransportProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Bandwidth values that may be supported for a specific profile.
  module Bandwidth
    # Unspecified bandwidth.
    BANDWIDTH_UNSPECIFIED = 0

    # 50 Megabits per second.
    BPS_50M = 1

    # 100 Megabits per second.
    BPS_100M = 2

    # 200 Megabits per second.
    BPS_200M = 3

    # 300 Megabits per second.
    BPS_300M = 4

    # 400 Megabits per second.
    BPS_400M = 5

    # 500 Megabits per second.
    BPS_500M = 6

    # 1 Gigabit per second.
    BPS_1G = 7

    # 2 Gigabits per second.
    BPS_2G = 8

    # 5 Gigabits per second.
    BPS_5G = 9

    # 10 Gigabits per second.
    BPS_10G = 10

    # 20 Gigabits per second.
    BPS_20G = 11

    # 50 Gigabits per second.
    BPS_50G = 12

    # 100 Gigabits per second.
    BPS_100G = 13
  end

  # Availability class options.
  module ServiceLevelAvailability
    # Unspecified service level availability.
    SERVICE_LEVEL_AVAILABILITY_UNSPECIFIED = 0

    # This represents a 99.9% service level on the availability of the
    # configured connectivity.
    HIGH = 1

    # This represents a 99.99% service level on the availability of the
    # configured connectivity.
    MAXIMUM = 2
  end

  # Type of provisioning flows supported.
  module KeyProvisioningFlow
    # Unspecified key provisioning flow.
    KEY_PROVISIONING_FLOW_UNSPECIFIED = 0

    # The activationKey field on the Transport must be included in a create or
    # patch request to establish connectivity.
    INPUT_ONLY = 1

    # The generatedActivationKey field is populated and must be read from the
    # resource and passed into the other provider.
    OUTPUT_ONLY = 2

    # Both activation key fields are allowed for establishing connectivity. If
    # a key is input, the generated key is still present after provisioning is
    # finished.
    INPUT_OR_OUTPUT = 3
  end

  # State of the RemoteTransportProfile.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Not enough capacity for customers to order.
    CLOSED = 1

    # Enough capacity to fulfill an order.
    OPEN = 2
  end
end

#display_name::String (readonly)

Returns Output only. Human readable name of this profile, used to identify this profile in the UI.

Returns:

  • (::String)

    Output only. Human readable name of this profile, used to identify this profile in the UI.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 62

class RemoteTransportProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Bandwidth values that may be supported for a specific profile.
  module Bandwidth
    # Unspecified bandwidth.
    BANDWIDTH_UNSPECIFIED = 0

    # 50 Megabits per second.
    BPS_50M = 1

    # 100 Megabits per second.
    BPS_100M = 2

    # 200 Megabits per second.
    BPS_200M = 3

    # 300 Megabits per second.
    BPS_300M = 4

    # 400 Megabits per second.
    BPS_400M = 5

    # 500 Megabits per second.
    BPS_500M = 6

    # 1 Gigabit per second.
    BPS_1G = 7

    # 2 Gigabits per second.
    BPS_2G = 8

    # 5 Gigabits per second.
    BPS_5G = 9

    # 10 Gigabits per second.
    BPS_10G = 10

    # 20 Gigabits per second.
    BPS_20G = 11

    # 50 Gigabits per second.
    BPS_50G = 12

    # 100 Gigabits per second.
    BPS_100G = 13
  end

  # Availability class options.
  module ServiceLevelAvailability
    # Unspecified service level availability.
    SERVICE_LEVEL_AVAILABILITY_UNSPECIFIED = 0

    # This represents a 99.9% service level on the availability of the
    # configured connectivity.
    HIGH = 1

    # This represents a 99.99% service level on the availability of the
    # configured connectivity.
    MAXIMUM = 2
  end

  # Type of provisioning flows supported.
  module KeyProvisioningFlow
    # Unspecified key provisioning flow.
    KEY_PROVISIONING_FLOW_UNSPECIFIED = 0

    # The activationKey field on the Transport must be included in a create or
    # patch request to establish connectivity.
    INPUT_ONLY = 1

    # The generatedActivationKey field is populated and must be read from the
    # resource and passed into the other provider.
    OUTPUT_ONLY = 2

    # Both activation key fields are allowed for establishing connectivity. If
    # a key is input, the generated key is still present after provisioning is
    # finished.
    INPUT_OR_OUTPUT = 3
  end

  # State of the RemoteTransportProfile.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Not enough capacity for customers to order.
    CLOSED = 1

    # Enough capacity to fulfill an order.
    OPEN = 2
  end
end

#flow::Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile::KeyProvisioningFlow (readonly)

Returns Output only. Type of provisioning flows supported by this profile.

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 62

class RemoteTransportProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Bandwidth values that may be supported for a specific profile.
  module Bandwidth
    # Unspecified bandwidth.
    BANDWIDTH_UNSPECIFIED = 0

    # 50 Megabits per second.
    BPS_50M = 1

    # 100 Megabits per second.
    BPS_100M = 2

    # 200 Megabits per second.
    BPS_200M = 3

    # 300 Megabits per second.
    BPS_300M = 4

    # 400 Megabits per second.
    BPS_400M = 5

    # 500 Megabits per second.
    BPS_500M = 6

    # 1 Gigabit per second.
    BPS_1G = 7

    # 2 Gigabits per second.
    BPS_2G = 8

    # 5 Gigabits per second.
    BPS_5G = 9

    # 10 Gigabits per second.
    BPS_10G = 10

    # 20 Gigabits per second.
    BPS_20G = 11

    # 50 Gigabits per second.
    BPS_50G = 12

    # 100 Gigabits per second.
    BPS_100G = 13
  end

  # Availability class options.
  module ServiceLevelAvailability
    # Unspecified service level availability.
    SERVICE_LEVEL_AVAILABILITY_UNSPECIFIED = 0

    # This represents a 99.9% service level on the availability of the
    # configured connectivity.
    HIGH = 1

    # This represents a 99.99% service level on the availability of the
    # configured connectivity.
    MAXIMUM = 2
  end

  # Type of provisioning flows supported.
  module KeyProvisioningFlow
    # Unspecified key provisioning flow.
    KEY_PROVISIONING_FLOW_UNSPECIFIED = 0

    # The activationKey field on the Transport must be included in a create or
    # patch request to establish connectivity.
    INPUT_ONLY = 1

    # The generatedActivationKey field is populated and must be read from the
    # resource and passed into the other provider.
    OUTPUT_ONLY = 2

    # Both activation key fields are allowed for establishing connectivity. If
    # a key is input, the generated key is still present after provisioning is
    # finished.
    INPUT_OR_OUTPUT = 3
  end

  # State of the RemoteTransportProfile.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Not enough capacity for customers to order.
    CLOSED = 1

    # Enough capacity to fulfill an order.
    OPEN = 2
  end
end

#labels::Google::Protobuf::Map{::String => ::String} (readonly)

Returns Output only. Labels as key value pairs.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Output only. Labels as key value pairs.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 62

class RemoteTransportProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Bandwidth values that may be supported for a specific profile.
  module Bandwidth
    # Unspecified bandwidth.
    BANDWIDTH_UNSPECIFIED = 0

    # 50 Megabits per second.
    BPS_50M = 1

    # 100 Megabits per second.
    BPS_100M = 2

    # 200 Megabits per second.
    BPS_200M = 3

    # 300 Megabits per second.
    BPS_300M = 4

    # 400 Megabits per second.
    BPS_400M = 5

    # 500 Megabits per second.
    BPS_500M = 6

    # 1 Gigabit per second.
    BPS_1G = 7

    # 2 Gigabits per second.
    BPS_2G = 8

    # 5 Gigabits per second.
    BPS_5G = 9

    # 10 Gigabits per second.
    BPS_10G = 10

    # 20 Gigabits per second.
    BPS_20G = 11

    # 50 Gigabits per second.
    BPS_50G = 12

    # 100 Gigabits per second.
    BPS_100G = 13
  end

  # Availability class options.
  module ServiceLevelAvailability
    # Unspecified service level availability.
    SERVICE_LEVEL_AVAILABILITY_UNSPECIFIED = 0

    # This represents a 99.9% service level on the availability of the
    # configured connectivity.
    HIGH = 1

    # This represents a 99.99% service level on the availability of the
    # configured connectivity.
    MAXIMUM = 2
  end

  # Type of provisioning flows supported.
  module KeyProvisioningFlow
    # Unspecified key provisioning flow.
    KEY_PROVISIONING_FLOW_UNSPECIFIED = 0

    # The activationKey field on the Transport must be included in a create or
    # patch request to establish connectivity.
    INPUT_ONLY = 1

    # The generatedActivationKey field is populated and must be read from the
    # resource and passed into the other provider.
    OUTPUT_ONLY = 2

    # Both activation key fields are allowed for establishing connectivity. If
    # a key is input, the generated key is still present after provisioning is
    # finished.
    INPUT_OR_OUTPUT = 3
  end

  # State of the RemoteTransportProfile.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Not enough capacity for customers to order.
    CLOSED = 1

    # Enough capacity to fulfill an order.
    OPEN = 2
  end
end

#name::String

Returns Identifier. Name of the resource in the format of $provider-$site.

Returns:

  • (::String)

    Identifier. Name of the resource in the format of $provider-$site.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 62

class RemoteTransportProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Bandwidth values that may be supported for a specific profile.
  module Bandwidth
    # Unspecified bandwidth.
    BANDWIDTH_UNSPECIFIED = 0

    # 50 Megabits per second.
    BPS_50M = 1

    # 100 Megabits per second.
    BPS_100M = 2

    # 200 Megabits per second.
    BPS_200M = 3

    # 300 Megabits per second.
    BPS_300M = 4

    # 400 Megabits per second.
    BPS_400M = 5

    # 500 Megabits per second.
    BPS_500M = 6

    # 1 Gigabit per second.
    BPS_1G = 7

    # 2 Gigabits per second.
    BPS_2G = 8

    # 5 Gigabits per second.
    BPS_5G = 9

    # 10 Gigabits per second.
    BPS_10G = 10

    # 20 Gigabits per second.
    BPS_20G = 11

    # 50 Gigabits per second.
    BPS_50G = 12

    # 100 Gigabits per second.
    BPS_100G = 13
  end

  # Availability class options.
  module ServiceLevelAvailability
    # Unspecified service level availability.
    SERVICE_LEVEL_AVAILABILITY_UNSPECIFIED = 0

    # This represents a 99.9% service level on the availability of the
    # configured connectivity.
    HIGH = 1

    # This represents a 99.99% service level on the availability of the
    # configured connectivity.
    MAXIMUM = 2
  end

  # Type of provisioning flows supported.
  module KeyProvisioningFlow
    # Unspecified key provisioning flow.
    KEY_PROVISIONING_FLOW_UNSPECIFIED = 0

    # The activationKey field on the Transport must be included in a create or
    # patch request to establish connectivity.
    INPUT_ONLY = 1

    # The generatedActivationKey field is populated and must be read from the
    # resource and passed into the other provider.
    OUTPUT_ONLY = 2

    # Both activation key fields are allowed for establishing connectivity. If
    # a key is input, the generated key is still present after provisioning is
    # finished.
    INPUT_OR_OUTPUT = 3
  end

  # State of the RemoteTransportProfile.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Not enough capacity for customers to order.
    CLOSED = 1

    # Enough capacity to fulfill an order.
    OPEN = 2
  end
end

#order_state::Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile::State (readonly)

Returns Output only. Order state for this profile.

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 62

class RemoteTransportProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Bandwidth values that may be supported for a specific profile.
  module Bandwidth
    # Unspecified bandwidth.
    BANDWIDTH_UNSPECIFIED = 0

    # 50 Megabits per second.
    BPS_50M = 1

    # 100 Megabits per second.
    BPS_100M = 2

    # 200 Megabits per second.
    BPS_200M = 3

    # 300 Megabits per second.
    BPS_300M = 4

    # 400 Megabits per second.
    BPS_400M = 5

    # 500 Megabits per second.
    BPS_500M = 6

    # 1 Gigabit per second.
    BPS_1G = 7

    # 2 Gigabits per second.
    BPS_2G = 8

    # 5 Gigabits per second.
    BPS_5G = 9

    # 10 Gigabits per second.
    BPS_10G = 10

    # 20 Gigabits per second.
    BPS_20G = 11

    # 50 Gigabits per second.
    BPS_50G = 12

    # 100 Gigabits per second.
    BPS_100G = 13
  end

  # Availability class options.
  module ServiceLevelAvailability
    # Unspecified service level availability.
    SERVICE_LEVEL_AVAILABILITY_UNSPECIFIED = 0

    # This represents a 99.9% service level on the availability of the
    # configured connectivity.
    HIGH = 1

    # This represents a 99.99% service level on the availability of the
    # configured connectivity.
    MAXIMUM = 2
  end

  # Type of provisioning flows supported.
  module KeyProvisioningFlow
    # Unspecified key provisioning flow.
    KEY_PROVISIONING_FLOW_UNSPECIFIED = 0

    # The activationKey field on the Transport must be included in a create or
    # patch request to establish connectivity.
    INPUT_ONLY = 1

    # The generatedActivationKey field is populated and must be read from the
    # resource and passed into the other provider.
    OUTPUT_ONLY = 2

    # Both activation key fields are allowed for establishing connectivity. If
    # a key is input, the generated key is still present after provisioning is
    # finished.
    INPUT_OR_OUTPUT = 3
  end

  # State of the RemoteTransportProfile.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Not enough capacity for customers to order.
    CLOSED = 1

    # Enough capacity to fulfill an order.
    OPEN = 2
  end
end

#provider::String (readonly)

Returns Output only. Name of the provider on the other end of this profile. E.g. “Amazon Web Services” or “Microsoft Azure”.

Returns:

  • (::String)

    Output only. Name of the provider on the other end of this profile. E.g. “Amazon Web Services” or “Microsoft Azure”.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 62

class RemoteTransportProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Bandwidth values that may be supported for a specific profile.
  module Bandwidth
    # Unspecified bandwidth.
    BANDWIDTH_UNSPECIFIED = 0

    # 50 Megabits per second.
    BPS_50M = 1

    # 100 Megabits per second.
    BPS_100M = 2

    # 200 Megabits per second.
    BPS_200M = 3

    # 300 Megabits per second.
    BPS_300M = 4

    # 400 Megabits per second.
    BPS_400M = 5

    # 500 Megabits per second.
    BPS_500M = 6

    # 1 Gigabit per second.
    BPS_1G = 7

    # 2 Gigabits per second.
    BPS_2G = 8

    # 5 Gigabits per second.
    BPS_5G = 9

    # 10 Gigabits per second.
    BPS_10G = 10

    # 20 Gigabits per second.
    BPS_20G = 11

    # 50 Gigabits per second.
    BPS_50G = 12

    # 100 Gigabits per second.
    BPS_100G = 13
  end

  # Availability class options.
  module ServiceLevelAvailability
    # Unspecified service level availability.
    SERVICE_LEVEL_AVAILABILITY_UNSPECIFIED = 0

    # This represents a 99.9% service level on the availability of the
    # configured connectivity.
    HIGH = 1

    # This represents a 99.99% service level on the availability of the
    # configured connectivity.
    MAXIMUM = 2
  end

  # Type of provisioning flows supported.
  module KeyProvisioningFlow
    # Unspecified key provisioning flow.
    KEY_PROVISIONING_FLOW_UNSPECIFIED = 0

    # The activationKey field on the Transport must be included in a create or
    # patch request to establish connectivity.
    INPUT_ONLY = 1

    # The generatedActivationKey field is populated and must be read from the
    # resource and passed into the other provider.
    OUTPUT_ONLY = 2

    # Both activation key fields are allowed for establishing connectivity. If
    # a key is input, the generated key is still present after provisioning is
    # finished.
    INPUT_OR_OUTPUT = 3
  end

  # State of the RemoteTransportProfile.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Not enough capacity for customers to order.
    CLOSED = 1

    # Enough capacity to fulfill an order.
    OPEN = 2
  end
end

#provider_site::String (readonly)

Returns Output only. If the profile is a Cloud Service Provider with compute resources, this is populated with the region where connectivity is being established. If the profile provides facility-level selection, this is an identity of the facility any connections on this profile are going through.

Returns:

  • (::String)

    Output only. If the profile is a Cloud Service Provider with compute resources, this is populated with the region where connectivity is being established. If the profile provides facility-level selection, this is an identity of the facility any connections on this profile are going through.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 62

class RemoteTransportProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Bandwidth values that may be supported for a specific profile.
  module Bandwidth
    # Unspecified bandwidth.
    BANDWIDTH_UNSPECIFIED = 0

    # 50 Megabits per second.
    BPS_50M = 1

    # 100 Megabits per second.
    BPS_100M = 2

    # 200 Megabits per second.
    BPS_200M = 3

    # 300 Megabits per second.
    BPS_300M = 4

    # 400 Megabits per second.
    BPS_400M = 5

    # 500 Megabits per second.
    BPS_500M = 6

    # 1 Gigabit per second.
    BPS_1G = 7

    # 2 Gigabits per second.
    BPS_2G = 8

    # 5 Gigabits per second.
    BPS_5G = 9

    # 10 Gigabits per second.
    BPS_10G = 10

    # 20 Gigabits per second.
    BPS_20G = 11

    # 50 Gigabits per second.
    BPS_50G = 12

    # 100 Gigabits per second.
    BPS_100G = 13
  end

  # Availability class options.
  module ServiceLevelAvailability
    # Unspecified service level availability.
    SERVICE_LEVEL_AVAILABILITY_UNSPECIFIED = 0

    # This represents a 99.9% service level on the availability of the
    # configured connectivity.
    HIGH = 1

    # This represents a 99.99% service level on the availability of the
    # configured connectivity.
    MAXIMUM = 2
  end

  # Type of provisioning flows supported.
  module KeyProvisioningFlow
    # Unspecified key provisioning flow.
    KEY_PROVISIONING_FLOW_UNSPECIFIED = 0

    # The activationKey field on the Transport must be included in a create or
    # patch request to establish connectivity.
    INPUT_ONLY = 1

    # The generatedActivationKey field is populated and must be read from the
    # resource and passed into the other provider.
    OUTPUT_ONLY = 2

    # Both activation key fields are allowed for establishing connectivity. If
    # a key is input, the generated key is still present after provisioning is
    # finished.
    INPUT_OR_OUTPUT = 3
  end

  # State of the RemoteTransportProfile.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Not enough capacity for customers to order.
    CLOSED = 1

    # Enough capacity to fulfill an order.
    OPEN = 2
  end
end

#sla::Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile::ServiceLevelAvailability (readonly)

Returns Output only. Availability class that will be configured for this particular RemoteTransportProfile.

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 62

class RemoteTransportProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Bandwidth values that may be supported for a specific profile.
  module Bandwidth
    # Unspecified bandwidth.
    BANDWIDTH_UNSPECIFIED = 0

    # 50 Megabits per second.
    BPS_50M = 1

    # 100 Megabits per second.
    BPS_100M = 2

    # 200 Megabits per second.
    BPS_200M = 3

    # 300 Megabits per second.
    BPS_300M = 4

    # 400 Megabits per second.
    BPS_400M = 5

    # 500 Megabits per second.
    BPS_500M = 6

    # 1 Gigabit per second.
    BPS_1G = 7

    # 2 Gigabits per second.
    BPS_2G = 8

    # 5 Gigabits per second.
    BPS_5G = 9

    # 10 Gigabits per second.
    BPS_10G = 10

    # 20 Gigabits per second.
    BPS_20G = 11

    # 50 Gigabits per second.
    BPS_50G = 12

    # 100 Gigabits per second.
    BPS_100G = 13
  end

  # Availability class options.
  module ServiceLevelAvailability
    # Unspecified service level availability.
    SERVICE_LEVEL_AVAILABILITY_UNSPECIFIED = 0

    # This represents a 99.9% service level on the availability of the
    # configured connectivity.
    HIGH = 1

    # This represents a 99.99% service level on the availability of the
    # configured connectivity.
    MAXIMUM = 2
  end

  # Type of provisioning flows supported.
  module KeyProvisioningFlow
    # Unspecified key provisioning flow.
    KEY_PROVISIONING_FLOW_UNSPECIFIED = 0

    # The activationKey field on the Transport must be included in a create or
    # patch request to establish connectivity.
    INPUT_ONLY = 1

    # The generatedActivationKey field is populated and must be read from the
    # resource and passed into the other provider.
    OUTPUT_ONLY = 2

    # Both activation key fields are allowed for establishing connectivity. If
    # a key is input, the generated key is still present after provisioning is
    # finished.
    INPUT_OR_OUTPUT = 3
  end

  # State of the RemoteTransportProfile.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Not enough capacity for customers to order.
    CLOSED = 1

    # Enough capacity to fulfill an order.
    OPEN = 2
  end
end

#supported_bandwidths::Array<::Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile::Bandwidth> (readonly)

Returns Output only. List of bandwidth enum values that are supported by this profile.

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 62

class RemoteTransportProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Bandwidth values that may be supported for a specific profile.
  module Bandwidth
    # Unspecified bandwidth.
    BANDWIDTH_UNSPECIFIED = 0

    # 50 Megabits per second.
    BPS_50M = 1

    # 100 Megabits per second.
    BPS_100M = 2

    # 200 Megabits per second.
    BPS_200M = 3

    # 300 Megabits per second.
    BPS_300M = 4

    # 400 Megabits per second.
    BPS_400M = 5

    # 500 Megabits per second.
    BPS_500M = 6

    # 1 Gigabit per second.
    BPS_1G = 7

    # 2 Gigabits per second.
    BPS_2G = 8

    # 5 Gigabits per second.
    BPS_5G = 9

    # 10 Gigabits per second.
    BPS_10G = 10

    # 20 Gigabits per second.
    BPS_20G = 11

    # 50 Gigabits per second.
    BPS_50G = 12

    # 100 Gigabits per second.
    BPS_100G = 13
  end

  # Availability class options.
  module ServiceLevelAvailability
    # Unspecified service level availability.
    SERVICE_LEVEL_AVAILABILITY_UNSPECIFIED = 0

    # This represents a 99.9% service level on the availability of the
    # configured connectivity.
    HIGH = 1

    # This represents a 99.99% service level on the availability of the
    # configured connectivity.
    MAXIMUM = 2
  end

  # Type of provisioning flows supported.
  module KeyProvisioningFlow
    # Unspecified key provisioning flow.
    KEY_PROVISIONING_FLOW_UNSPECIFIED = 0

    # The activationKey field on the Transport must be included in a create or
    # patch request to establish connectivity.
    INPUT_ONLY = 1

    # The generatedActivationKey field is populated and must be read from the
    # resource and passed into the other provider.
    OUTPUT_ONLY = 2

    # Both activation key fields are allowed for establishing connectivity. If
    # a key is input, the generated key is still present after provisioning is
    # finished.
    INPUT_OR_OUTPUT = 3
  end

  # State of the RemoteTransportProfile.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Not enough capacity for customers to order.
    CLOSED = 1

    # Enough capacity to fulfill an order.
    OPEN = 2
  end
end