Module: Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile::KeyProvisioningFlow

Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb

Overview

Type of provisioning flows supported.

Constant Summary collapse

KEY_PROVISIONING_FLOW_UNSPECIFIED =

Unspecified key provisioning flow.

0
INPUT_ONLY =

The activationKey field on the Transport must be included in a create or patch request to establish connectivity.

1
OUTPUT_ONLY =

The generatedActivationKey field is populated and must be read from the resource and passed into the other provider.

2
INPUT_OR_OUTPUT =

Both activation key fields are allowed for establishing connectivity. If a key is input, the generated key is still present after provisioning is finished.

3