Class: Google::Cloud::NetworkConnectivity::V1beta::Route
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::Route
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
A route defines a path from VM instances within a spoke to a specific destination resource. Only VPC spokes have routes.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
An optional description of the route.
-
#ip_cidr_range ⇒ ::String
The destination IP address range.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional labels in key-value pair format.
-
#location ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Immutable.
-
#next_hop_interconnect_attachment ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::NextHopInterconnectAttachment
Immutable.
-
#next_hop_router_appliance_instance ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::NextHopRouterApplianceInstance
Immutable.
-
#next_hop_spoke ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::NextHopSpoke
Immutable.
-
#next_hop_vpc_network ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::NextHopVpcNetwork
Immutable.
-
#next_hop_vpn_tunnel ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::NextHopVPNTunnel
Immutable.
-
#priority ⇒ ::Integer
readonly
Output only.
-
#spoke ⇒ ::String
Immutable.
-
#state ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::State
readonly
Output only.
-
#type ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::RouteType
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the route was created.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns An optional description of the route.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ip_cidr_range ⇒ ::String
Returns The destination IP address range.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional labels in key-value pair format. For more information about labels, see Requirements for labels.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#location ⇒ ::String (readonly)
Returns Output only. The origin location of the route. Uses the following form: "projects/{project}/locations/{location}" Example: projects/1234/locations/us-central1.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Immutable. The name of the route. Route names must be unique. Route names
use the following form:
projects/{project_number}/locations/global/hubs/{hub}/routeTables/{route_table_id}/routes/{route_id}.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_hop_interconnect_attachment ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::NextHopInterconnectAttachment
Returns Immutable. The next-hop VLAN attachment for packets on this route.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_hop_router_appliance_instance ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::NextHopRouterApplianceInstance
Returns Immutable. The next-hop Router appliance instance for packets on this route.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_hop_spoke ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::NextHopSpoke
Returns Immutable. The next-hop spoke for packets on this route.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_hop_vpc_network ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::NextHopVpcNetwork
Returns Immutable. The destination VPC network for packets on this route.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_hop_vpn_tunnel ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::NextHopVPNTunnel
Returns Immutable. The next-hop VPN tunnel for packets on this route.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#priority ⇒ ::Integer (readonly)
Returns Output only. The priority of this route. Priority is used to break ties in cases where a destination matches more than one route. In these cases the route with the lowest-numbered priority value wins.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#spoke ⇒ ::String
Returns Immutable. The spoke that this route leads to. Example: projects/12345/locations/global/spokes/SPOKE.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#state ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::State (readonly)
Returns Output only. The current lifecycle state of the route.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#type ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::RouteType (readonly)
Returns Output only. The route's type. Its type is determined by the properties of its IP address range.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uid ⇒ ::String (readonly)
Returns Output only. The Google-generated UUID for the route. This value is unique
across all Network Connectivity Center route resources. If a
route is deleted and another with the same name is created,
the new route is assigned a different uid.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the route was last updated.
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 392 class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |