Class: Google::Cloud::NetworkConnectivity::V1beta::Spoke::StateReason

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb

Overview

The reason for the current state of the spoke.

Defined Under Namespace

Modules: Code

Instance Attribute Summary collapse

Instance Attribute Details

#code::Google::Cloud::NetworkConnectivity::V1beta::Spoke::StateReason::Code

Returns The code associated with this reason.

Returns:



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 239

class StateReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Code enum represents the various reasons for the state of the spoke.
  module Code
    # No information available.
    CODE_UNSPECIFIED = 0

    # The proposed spoke is pending review.
    PENDING_REVIEW = 1

    # The proposed spoke has been rejected by the hub administrator.
    REJECTED = 2

    # The spoke has been deactivated internally.
    PAUSED = 3

    # Network Connectivity Center encountered errors while accepting
    # the spoke.
    FAILED = 4

    # The proposed spoke update is pending review.
    UPDATE_PENDING_REVIEW = 5

    # The proposed spoke update has been rejected by the hub administrator.
    UPDATE_REJECTED = 6

    # Network Connectivity Center encountered errors while accepting
    # the spoke update.
    UPDATE_FAILED = 7
  end
end

#message::String

Returns Human-readable details about this reason.

Returns:

  • (::String)

    Human-readable details about this reason.



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 239

class StateReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Code enum represents the various reasons for the state of the spoke.
  module Code
    # No information available.
    CODE_UNSPECIFIED = 0

    # The proposed spoke is pending review.
    PENDING_REVIEW = 1

    # The proposed spoke has been rejected by the hub administrator.
    REJECTED = 2

    # The spoke has been deactivated internally.
    PAUSED = 3

    # Network Connectivity Center encountered errors while accepting
    # the spoke.
    FAILED = 4

    # The proposed spoke update is pending review.
    UPDATE_PENDING_REVIEW = 5

    # The proposed spoke update has been rejected by the hub administrator.
    UPDATE_REJECTED = 6

    # Network Connectivity Center encountered errors while accepting
    # the spoke update.
    UPDATE_FAILED = 7
  end
end

#user_details::String

Returns Additional information provided by the user in the RejectSpoke call.

Returns:

  • (::String)

    Additional information provided by the user in the RejectSpoke call.



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 239

class StateReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Code enum represents the various reasons for the state of the spoke.
  module Code
    # No information available.
    CODE_UNSPECIFIED = 0

    # The proposed spoke is pending review.
    PENDING_REVIEW = 1

    # The proposed spoke has been rejected by the hub administrator.
    REJECTED = 2

    # The spoke has been deactivated internally.
    PAUSED = 3

    # Network Connectivity Center encountered errors while accepting
    # the spoke.
    FAILED = 4

    # The proposed spoke update is pending review.
    UPDATE_PENDING_REVIEW = 5

    # The proposed spoke update has been rejected by the hub administrator.
    UPDATE_REJECTED = 6

    # Network Connectivity Center encountered errors while accepting
    # the spoke update.
    UPDATE_FAILED = 7
  end
end