Class: Google::Cloud::NetworkConnectivity::V1beta::Transport
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::Transport
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb
Overview
Message describing Transport object.
Defined Under Namespace
Modules: Bandwidth, StackType, State Classes: LabelsEntry
Instance Attribute Summary collapse
-
#admin_enabled ⇒ ::Boolean
Optional.
-
#advertised_routes ⇒ ::Array<::String>
Optional.
-
#bandwidth ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::Transport::Bandwidth
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#generated_activation_key ⇒ ::String
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#mtu_limit ⇒ ::Integer
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#network ⇒ ::String
Optional.
-
#peering_network ⇒ ::String
readonly
Output only.
-
#provided_activation_key ⇒ ::String
Optional.
-
#remote_account_id ⇒ ::String
Optional.
-
#remote_profile ⇒ ::String
Optional.
-
#stack_type ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::Transport::StackType
Optional.
-
#state ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::Transport::State
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#admin_enabled ⇒ ::Boolean
Returns Optional. Administrative state of the underlying connectivity. If set to true (default), connectivity should be available between your environments. If set to false, the connectivity over these links is disabled. Disabling your Transport does not affect billing, and retains the underlying network bandwidth associated with the connectivity.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#advertised_routes ⇒ ::Array<::String>
Returns Optional. List of IP Prefixes that will be advertised to the remote provider. Both IPv4 and IPv6 addresses are supported.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#bandwidth ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::Transport::Bandwidth
Returns Optional. Bandwidth of the Transport. This must be one of the supported bandwidths for the remote profile, and must be set when no activation key is being provided.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Create time stamp.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#description ⇒ ::String
Returns Optional. Description of the Transport.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#generated_activation_key ⇒ ::String (readonly)
Returns Output only. Google-generated activation key. This is only output if the selected profile supports an OUTPUT key flow. Inputting this to the provider is only valid while the resource is in a PENDING_KEY state. Once the provider has accepted the key, the resource will move to the CONFIGURING state.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels as key value pairs.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#mtu_limit ⇒ ::Integer (readonly)
Returns Output only. The maximum transmission unit (MTU) of a packet that can be sent over this transport.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#name ⇒ ::String
Returns Identifier. Name of the resource.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#network ⇒ ::String
Returns Optional. Resource URI of the Network that will be peered with this Transport. This field must be provided during resource creation and cannot be changed.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#peering_network ⇒ ::String (readonly)
Returns Output only. VPC Network URI that was created for the VPC Peering
connection to the provided network. If VPC Peering is disconnected, this
can be used to re-establish.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#provided_activation_key ⇒ ::String
Returns Optional. Key used for establishing a connection with the remote transport. This key can only be provided if the profile supports an INPUT key flow and the resource is in the PENDING_KEY state.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#remote_account_id ⇒ ::String
Returns Optional. The user supplied account id for the CSP associated with the remote profile.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#remote_profile ⇒ ::String
Returns Optional. Name of the remoteTransportProfile that this Transport is connecting to.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#stack_type ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::Transport::StackType
Returns Optional. IP version stack for the established connectivity.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#state ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::Transport::State (readonly)
Returns Output only. State of the underlying connectivity.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Update time stamp.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 284 class Transport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Supported bandwidth options. module Bandwidth # Unspecified bandwidth. BANDWIDTH_UNSPECIFIED = 0 # 50 Megabits per second. BPS_50M = 1 # 100 Megabits per second. BPS_100M = 2 # 200 Megabits per second. BPS_200M = 3 # 300 Megabits per second. BPS_300M = 4 # 400 Megabits per second. BPS_400M = 5 # 500 Megabits per second. BPS_500M = 6 # 1 Gigabit per second. BPS_1G = 7 # 2 Gigabits per second. BPS_2G = 8 # 5 Gigabits per second. BPS_5G = 9 # 10 Gigabits per second. BPS_10G = 10 # 20 Gigabits per second. BPS_20G = 11 # 50 Gigabits per second. BPS_50G = 12 # 100 Gigabits per second. BPS_100G = 13 end # IP version stack for the established connectivity. module StackType # Unspecified stack type. STACK_TYPE_UNSPECIFIED = 0 # Only IPv4 is supported. (default) IPV4_ONLY = 1 # Both IPv4 and IPv6 are supported. IPV4_IPV6 = 2 end # Represents the status of the underlying connectivity. One of # the following states, depending on who has initiated the Transport request. module State # Unspecified state. STATE_UNSPECIFIED = 0 # The resource exists locally and is being created / associated with the # resource on the remote provider’s end of the underlying connectivity. CREATING = 1 # The Transport exists on both sides of the connection, and is waiting for # configuration to finalize and be verified as operational. PENDING_CONFIG = 2 # The Transport was created in GCP. Depending on the profile’s key # provisioning flow, this is either waiting for an activation key to be # input (the key will be validated that it uses remote resources that match # the Transport), or for the generated key to be input to the provider for # finalizing. The configured bandwidth is not yet guaranteed. PENDING_KEY = 3 # The Transport is configured and the underlying connectivity is considered # operational. ACTIVE = 4 # The Transport is being deleted from GCP. The underlying connectivity is # no longer operational. DELETING = 5 # The Transport was deleted on the remote provider's end and is no longer # operational. GCP has insufficient information to move the resource back # to PENDING_KEY state. DEPROVISIONED = 6 end end |