Module: Google::Cloud::NetworkConnectivity::V1beta::Transport::State

Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb

Overview

Represents the status of the underlying connectivity. One of the following states, depending on who has initiated the Transport request.

Constant Summary collapse

STATE_UNSPECIFIED =

Unspecified state.

0
CREATING =

The resource exists locally and is being created / associated with the resource on the remote provider’s end of the underlying connectivity.

1
PENDING_CONFIG =

The Transport exists on both sides of the connection, and is waiting for configuration to finalize and be verified as operational.

2
PENDING_KEY =

The Transport was created in GCP. Depending on the profile’s key provisioning flow, this is either waiting for an activation key to be input (the key will be validated that it uses remote resources that match the Transport), or for the generated key to be input to the provider for finalizing. The configured bandwidth is not yet guaranteed.

3
ACTIVE =

The Transport is configured and the underlying connectivity is considered operational.

4
DELETING =

The Transport is being deleted from GCP. The underlying connectivity is no longer operational.

5
DEPROVISIONED =

The Transport was deleted on the remote provider's end and is no longer operational. GCP has insufficient information to move the resource back to PENDING_KEY state.

6