Class: Google::Cloud::NetworkConnectivity::V1beta::TransportManager::Client
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::TransportManager::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb
Overview
Client for the TransportManager service.
The CLH based service for managing RemoteTransportProfiles and Transports.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client
readonly
Get the associated client for mix-in of the IAMPolicy.
-
#location_client ⇒ Google::Cloud::Location::Locations::Client
readonly
Get the associated client for mix-in of the Locations.
-
#operations_client ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::TransportManager::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the TransportManager Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the TransportManager Client instance.
-
#create_transport(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Creates a new Transport in a given project and location.
-
#delete_transport(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Deletes a single Transport.
-
#get_remote_transport_profile(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile
Gets details of a single RemoteTransportProfile.
-
#get_status(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse
Gets the operational status of a single Transport.
-
#get_transport(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::Transport
Gets details of a single Transport.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new TransportManager client object.
-
#list_remote_transport_profiles(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile>
Lists RemoteTransportProfiles in a given project and location.
-
#list_transports(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkConnectivity::V1beta::Transport>
Lists Transports in a given project and location.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#parse_from_activation_key(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::ParseFromActivationKeyResponse
Gets details of a single RemoteTransportProfile given an activation key.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_transport(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Updates the parameters of a single Transport.
Methods included from Paths
#hub_path, #location_path, #network_path, #remote_transport_profile_path, #transport_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new TransportManager client object.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 137 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/networkconnectivity/v1beta/transport_manager_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @transport_manager_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::NetworkConnectivity::V1beta::TransportManager::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @transport_manager_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @transport_manager_stub.endpoint config.universe_domain = @transport_manager_stub.universe_domain config.logger = @transport_manager_stub.logger if config.respond_to? :logger= end @iam_policy_client = Google::Iam::V1::IAMPolicy::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @transport_manager_stub.endpoint config.universe_domain = @transport_manager_stub.universe_domain config.logger = @transport_manager_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client (readonly)
Get the associated client for mix-in of the IAMPolicy.
230 231 232 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 230 def iam_policy_client @iam_policy_client end |
#location_client ⇒ Google::Cloud::Location::Locations::Client (readonly)
Get the associated client for mix-in of the Locations.
223 224 225 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 223 def location_client @location_client end |
#operations_client ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::TransportManager::Operations (readonly)
Get the associated client for long-running operations.
216 217 218 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 216 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the TransportManager Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "NetworkConnectivity", "V1beta"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 60.0 default_config.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.create_transport.timeout = 60.0 default_config.rpcs.update_transport.timeout = 60.0 default_config.rpcs.delete_transport.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the TransportManager Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
107 108 109 110 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 107 def configure yield @config if block_given? @config end |
#create_transport(request, options = nil) ⇒ ::Gapic::Operation #create_transport(parent: nil, transport_id: nil, transport: nil, request_id: nil) ⇒ ::Gapic::Operation
Creates a new Transport in a given project and location.
857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 857 def create_transport request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkConnectivity::V1beta::CreateTransportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_transport..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkConnectivity::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_transport.timeout, metadata: , retry_policy: @config.rpcs.create_transport.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @transport_manager_stub.call_rpc :create_transport, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_transport(request, options = nil) ⇒ ::Gapic::Operation #delete_transport(name: nil, request_id: nil) ⇒ ::Gapic::Operation
Deletes a single Transport.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 1080 def delete_transport request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkConnectivity::V1beta::DeleteTransportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_transport..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkConnectivity::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_transport.timeout, metadata: , retry_policy: @config.rpcs.delete_transport.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @transport_manager_stub.call_rpc :delete_transport, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_remote_transport_profile(request, options = nil) ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile #get_remote_transport_profile(name: nil) ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile
Gets details of a single RemoteTransportProfile.
387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 387 def get_remote_transport_profile request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkConnectivity::V1beta::GetRemoteTransportProfileRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_remote_transport_profile..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkConnectivity::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_remote_transport_profile.timeout, metadata: , retry_policy: @config.rpcs.get_remote_transport_profile.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @transport_manager_stub.call_rpc :get_remote_transport_profile, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_status(request, options = nil) ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse #get_status(name: nil, skip_cache: nil) ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse
Gets the operational status of a single Transport.
747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 747 def get_status request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkConnectivity::V1beta::GetStatusRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_status..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkConnectivity::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_status.timeout, metadata: , retry_policy: @config.rpcs.get_status.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @transport_manager_stub.call_rpc :get_status, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_transport(request, options = nil) ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::Transport #get_transport(name: nil) ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::Transport
Gets details of a single Transport.
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 659 def get_transport request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkConnectivity::V1beta::GetTransportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_transport..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkConnectivity::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_transport.timeout, metadata: , retry_policy: @config.rpcs.get_transport.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @transport_manager_stub.call_rpc :get_transport, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_remote_transport_profiles(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile> #list_remote_transport_profiles(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile>
Lists RemoteTransportProfiles in a given project and location.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 300 def list_remote_transport_profiles request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkConnectivity::V1beta::ListRemoteTransportProfilesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_remote_transport_profiles..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkConnectivity::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_remote_transport_profiles.timeout, metadata: , retry_policy: @config.rpcs.list_remote_transport_profiles.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @transport_manager_stub.call_rpc :list_remote_transport_profiles, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @transport_manager_stub, :list_remote_transport_profiles, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_transports(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkConnectivity::V1beta::Transport> #list_transports(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkConnectivity::V1beta::Transport>
Lists Transports in a given project and location.
572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 572 def list_transports request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkConnectivity::V1beta::ListTransportsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_transports..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkConnectivity::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_transports.timeout, metadata: , retry_policy: @config.rpcs.list_transports.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @transport_manager_stub.call_rpc :list_transports, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @transport_manager_stub, :list_transports, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
237 238 239 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 237 def logger @transport_manager_stub.logger end |
#parse_from_activation_key(request, options = nil) ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::ParseFromActivationKeyResponse #parse_from_activation_key(parent: nil, activation_key: nil) ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::ParseFromActivationKeyResponse
Gets details of a single RemoteTransportProfile given an activation key.
474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 474 def parse_from_activation_key request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkConnectivity::V1beta::ParseFromActivationKeyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.parse_from_activation_key..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkConnectivity::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.parse_from_activation_key.timeout, metadata: , retry_policy: @config.rpcs.parse_from_activation_key.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @transport_manager_stub.call_rpc :parse_from_activation_key, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
117 118 119 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 117 def universe_domain @transport_manager_stub.universe_domain end |
#update_transport(request, options = nil) ⇒ ::Gapic::Operation #update_transport(update_mask: nil, transport: nil, request_id: nil) ⇒ ::Gapic::Operation
Updates the parameters of a single Transport.
972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 |
# File 'lib/google/cloud/network_connectivity/v1beta/transport_manager/client.rb', line 972 def update_transport request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkConnectivity::V1beta::UpdateTransportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_transport..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkConnectivity::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.transport&.name header_params["transport.name"] = request.transport.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_transport.timeout, metadata: , retry_policy: @config.rpcs.update_transport.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @transport_manager_stub.call_rpc :update_transport, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |