Class: Google::Cloud::NetworkConnectivity::V1beta::UpdateGatewayAdvertisedRouteRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::UpdateGatewayAdvertisedRouteRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
The request for HubService.UpdateGatewayAdvertisedRoute.
Instance Attribute Summary collapse
-
#gateway_advertised_route ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::GatewayAdvertisedRoute
Required.
-
#request_id ⇒ ::String
Optional.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#gateway_advertised_route ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::GatewayAdvertisedRoute
Returns Required. The gateway advertised route to update.
The gateway advertised route's name field is used to identify the gateway
advertised route to update. Format:
projects/{project}/locations/{location}/spokes/{spoke}/gatewayAdvertisedRoutes/{gatewayAdvertisedRoute}.
1620 1621 1622 1623 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1620 class UpdateGatewayAdvertisedRouteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that a request doesn't result in creation of duplicate commitments for at least 60 minutes.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check to see whether the original operation was received. If it was, the server ignores the second request. This behavior prevents clients from mistakenly creating duplicate commitments.
The request ID must be a valid UUID, with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
1620 1621 1622 1623 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1620 class UpdateGatewayAdvertisedRouteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. In the case of an update to an existing group, field mask is used to specify the fields to be overwritten. The fields specified in the update_mask are relative to the resource, not the full request. A field is overwritten if it is in the mask. If the user does not provide a mask, then all fields are overwritten.
1620 1621 1622 1623 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1620 class UpdateGatewayAdvertisedRouteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |