Class: Google::Cloud::NetworkConnectivity::V1beta::CreateGatewayAdvertisedRouteRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#gateway_advertised_route::Google::Cloud::NetworkConnectivity::V1beta::GatewayAdvertisedRoute

Returns Required. Initial values for the new gateway advertised route.

Returns:



1526
1527
1528
1529
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1526

class CreateGatewayAdvertisedRouteRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gateway_advertised_route_id::String

Returns Required. Unique id for the route to create.

Returns:

  • (::String)

    Required. Unique id for the route to create.



1526
1527
1528
1529
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1526

class CreateGatewayAdvertisedRouteRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource.

Returns:

  • (::String)

    Required. The parent resource.



1526
1527
1528
1529
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1526

class CreateGatewayAdvertisedRouteRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that a request doesn't result in creation of duplicate commitments for at least 60 minutes.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check to see whether the original operation was received. If it was, the server ignores the second request. This behavior prevents clients from mistakenly creating duplicate commitments.

The request ID must be a valid UUID, with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that a request doesn't result in creation of duplicate commitments for at least 60 minutes.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check to see whether the original operation was received. If it was, the server ignores the second request. This behavior prevents clients from mistakenly creating duplicate commitments.

    The request ID must be a valid UUID, with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



1526
1527
1528
1529
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1526

class CreateGatewayAdvertisedRouteRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end