Class: Google::Cloud::NetworkConnectivity::V1beta::DeleteGatewayAdvertisedRouteRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::DeleteGatewayAdvertisedRouteRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
Request for HubService.DeleteGatewayAdvertisedRoute method.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The name of the gateway advertised route to delete.
1647 1648 1649 1650 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1647 class DeleteGatewayAdvertisedRouteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that a request doesn't result in creation of duplicate commitments for at least 60 minutes.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check to see whether the original operation was received. If it was, the server ignores the second request. This behavior prevents clients from mistakenly creating duplicate commitments.
The request ID must be a valid UUID, with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
1647 1648 1649 1650 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1647 class DeleteGatewayAdvertisedRouteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |