Class: Google::Cloud::NetworkConnectivity::V1beta::Gateway::IpRangeReservation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb

Overview

A list of IP ranges that are reserved for this gateway's internal intfrastructure.

Instance Attribute Summary collapse

Instance Attribute Details

#ip_range::String

Returns Required. A block of IP addresses used to allocate supporting infrastructure for this gateway. This block must not overlap with subnets in any spokes or peer VPC networks that the gateway can communicate with. Example: "10.1.2.0/24".

Returns:

  • (::String)

    Required. A block of IP addresses used to allocate supporting infrastructure for this gateway. This block must not overlap with subnets in any spokes or peer VPC networks that the gateway can communicate with. Example: "10.1.2.0/24"



1409
1410
1411
1412
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1409

class IpRangeReservation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end