Class: Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb

Overview

Message for the response to getting a Transport's operational status.

Defined Under Namespace

Modules: ConnectivityStatus, MacSecStatus, OperationalStatus, OverallStatus

Instance Attribute Summary collapse

Instance Attribute Details

#connectivity_status::Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse::ConnectivityStatus

Returns Current status of connectivity to the local GCP resource. This reflects whether the VPC Peering or NCC Hub appears correctly configured.

Returns:



463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 463

class GetStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The overall status of the Transport.
  module OverallStatus
    # Unspecified status.
    OVERALL_STATUS_UNSPECIFIED = 0

    # Resource is active and operational.
    ACTIVE = 1

    # Resource is waiting for an activation key to be exchanged.
    PENDING_KEY = 2

    # Activation keys have been exchanged and connectivity is being
    # established.
    CONFIGURING = 3

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    DISCONNECTED = 4

    # User configuration is correct, but the configured capacity is
    # operationally down.
    DOWN = 5
  end

  # The operational status of the underlying networking components.
  module OperationalStatus
    # Unspecified status.
    OPERATIONAL_STATUS_UNSPECIFIED = 0

    # Protected capacity is available and networking components show as up.
    OPERATIONAL_STATUS_ACTIVE = 1

    # Protected capacity is showing as operationally down.
    OPERATIONAL_STATUS_DOWN = 2
  end

  # Current status of connectivity to the local GCP resource. This reflects
  # whether the VPC Peering or NCC Hub appears correctly configured.
  module ConnectivityStatus
    # Unspecified status.
    CONNECTIVITY_STATUS_UNSPECIFIED = 0

    # VPC Peering or the NCC Hub appear to be correctly established.
    CONNECTIVITY_STATUS_CONNECTED = 1

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    CONNECTIVITY_STATUS_DISCONNECTED = 2
  end

  # Current status of MACSec on the underlying network connectivity between GC
  # and the partner.
  module MacSecStatus
    # Unspecified status.
    MAC_SEC_STATUS_UNSPECIFIED = 0

    # MACSec is protecting the links and configured in fail closed.
    MAC_SEC_STATUS_ACTIVE_FAIL_CLOSED = 1

    # MACSec is protecting the links and configured to fail open on at least
    # one of the redundant links.
    MAC_SEC_STATUS_ACTIVE_FAIL_OPEN = 2

    # MACSec is not configured on at least one of the underlying links.
    MAC_SEC_STATUS_NOT_CONFIGURED = 3
  end
end

#mac_sec_status::Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse::MacSecStatus

Returns Current status of MACSec on the underlying network connectivity between GC and the partner.

Returns:



463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 463

class GetStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The overall status of the Transport.
  module OverallStatus
    # Unspecified status.
    OVERALL_STATUS_UNSPECIFIED = 0

    # Resource is active and operational.
    ACTIVE = 1

    # Resource is waiting for an activation key to be exchanged.
    PENDING_KEY = 2

    # Activation keys have been exchanged and connectivity is being
    # established.
    CONFIGURING = 3

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    DISCONNECTED = 4

    # User configuration is correct, but the configured capacity is
    # operationally down.
    DOWN = 5
  end

  # The operational status of the underlying networking components.
  module OperationalStatus
    # Unspecified status.
    OPERATIONAL_STATUS_UNSPECIFIED = 0

    # Protected capacity is available and networking components show as up.
    OPERATIONAL_STATUS_ACTIVE = 1

    # Protected capacity is showing as operationally down.
    OPERATIONAL_STATUS_DOWN = 2
  end

  # Current status of connectivity to the local GCP resource. This reflects
  # whether the VPC Peering or NCC Hub appears correctly configured.
  module ConnectivityStatus
    # Unspecified status.
    CONNECTIVITY_STATUS_UNSPECIFIED = 0

    # VPC Peering or the NCC Hub appear to be correctly established.
    CONNECTIVITY_STATUS_CONNECTED = 1

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    CONNECTIVITY_STATUS_DISCONNECTED = 2
  end

  # Current status of MACSec on the underlying network connectivity between GC
  # and the partner.
  module MacSecStatus
    # Unspecified status.
    MAC_SEC_STATUS_UNSPECIFIED = 0

    # MACSec is protecting the links and configured in fail closed.
    MAC_SEC_STATUS_ACTIVE_FAIL_CLOSED = 1

    # MACSec is protecting the links and configured to fail open on at least
    # one of the redundant links.
    MAC_SEC_STATUS_ACTIVE_FAIL_OPEN = 2

    # MACSec is not configured on at least one of the underlying links.
    MAC_SEC_STATUS_NOT_CONFIGURED = 3
  end
end

#operational_status::Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse::OperationalStatus

Returns The operational status of the underlying networking components.

Returns:



463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 463

class GetStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The overall status of the Transport.
  module OverallStatus
    # Unspecified status.
    OVERALL_STATUS_UNSPECIFIED = 0

    # Resource is active and operational.
    ACTIVE = 1

    # Resource is waiting for an activation key to be exchanged.
    PENDING_KEY = 2

    # Activation keys have been exchanged and connectivity is being
    # established.
    CONFIGURING = 3

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    DISCONNECTED = 4

    # User configuration is correct, but the configured capacity is
    # operationally down.
    DOWN = 5
  end

  # The operational status of the underlying networking components.
  module OperationalStatus
    # Unspecified status.
    OPERATIONAL_STATUS_UNSPECIFIED = 0

    # Protected capacity is available and networking components show as up.
    OPERATIONAL_STATUS_ACTIVE = 1

    # Protected capacity is showing as operationally down.
    OPERATIONAL_STATUS_DOWN = 2
  end

  # Current status of connectivity to the local GCP resource. This reflects
  # whether the VPC Peering or NCC Hub appears correctly configured.
  module ConnectivityStatus
    # Unspecified status.
    CONNECTIVITY_STATUS_UNSPECIFIED = 0

    # VPC Peering or the NCC Hub appear to be correctly established.
    CONNECTIVITY_STATUS_CONNECTED = 1

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    CONNECTIVITY_STATUS_DISCONNECTED = 2
  end

  # Current status of MACSec on the underlying network connectivity between GC
  # and the partner.
  module MacSecStatus
    # Unspecified status.
    MAC_SEC_STATUS_UNSPECIFIED = 0

    # MACSec is protecting the links and configured in fail closed.
    MAC_SEC_STATUS_ACTIVE_FAIL_CLOSED = 1

    # MACSec is protecting the links and configured to fail open on at least
    # one of the redundant links.
    MAC_SEC_STATUS_ACTIVE_FAIL_OPEN = 2

    # MACSec is not configured on at least one of the underlying links.
    MAC_SEC_STATUS_NOT_CONFIGURED = 3
  end
end

#overall_status::Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse::OverallStatus

Returns The overall status of the Transport. This field will always output the most critical status of the Transport. For example, if the connectivity is DISCONNECTED, and the underlying networking components are DOWN, then the overall status will be DOWN.

Returns:



463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb', line 463

class GetStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The overall status of the Transport.
  module OverallStatus
    # Unspecified status.
    OVERALL_STATUS_UNSPECIFIED = 0

    # Resource is active and operational.
    ACTIVE = 1

    # Resource is waiting for an activation key to be exchanged.
    PENDING_KEY = 2

    # Activation keys have been exchanged and connectivity is being
    # established.
    CONFIGURING = 3

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    DISCONNECTED = 4

    # User configuration is correct, but the configured capacity is
    # operationally down.
    DOWN = 5
  end

  # The operational status of the underlying networking components.
  module OperationalStatus
    # Unspecified status.
    OPERATIONAL_STATUS_UNSPECIFIED = 0

    # Protected capacity is available and networking components show as up.
    OPERATIONAL_STATUS_ACTIVE = 1

    # Protected capacity is showing as operationally down.
    OPERATIONAL_STATUS_DOWN = 2
  end

  # Current status of connectivity to the local GCP resource. This reflects
  # whether the VPC Peering or NCC Hub appears correctly configured.
  module ConnectivityStatus
    # Unspecified status.
    CONNECTIVITY_STATUS_UNSPECIFIED = 0

    # VPC Peering or the NCC Hub appear to be correctly established.
    CONNECTIVITY_STATUS_CONNECTED = 1

    # VPC Peering has been taken down, or the NCC Spoke has been rejected.
    CONNECTIVITY_STATUS_DISCONNECTED = 2
  end

  # Current status of MACSec on the underlying network connectivity between GC
  # and the partner.
  module MacSecStatus
    # Unspecified status.
    MAC_SEC_STATUS_UNSPECIFIED = 0

    # MACSec is protecting the links and configured in fail closed.
    MAC_SEC_STATUS_ACTIVE_FAIL_CLOSED = 1

    # MACSec is protecting the links and configured to fail open on at least
    # one of the redundant links.
    MAC_SEC_STATUS_ACTIVE_FAIL_OPEN = 2

    # MACSec is not configured on at least one of the underlying links.
    MAC_SEC_STATUS_NOT_CONFIGURED = 3
  end
end