Module: Google::Cloud::NetworkConnectivity::V1beta::GetStatusResponse::MacSecStatus
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb
Overview
Current status of MACSec on the underlying network connectivity between GC and the partner.
Constant Summary collapse
- MAC_SEC_STATUS_UNSPECIFIED =
Unspecified status.
0- MAC_SEC_STATUS_ACTIVE_FAIL_CLOSED =
MACSec is protecting the links and configured in fail closed.
1- MAC_SEC_STATUS_ACTIVE_FAIL_OPEN =
MACSec is protecting the links and configured to fail open on at least one of the redundant links.
2- MAC_SEC_STATUS_NOT_CONFIGURED =
MACSec is not configured on at least one of the underlying links.
3