Class: Google::Cloud::NetworkConnectivity::V1beta::Hub::ExportPscConfig
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::Hub::ExportPscConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
Configuration for more granular control of Private Service Connect connection propagation. This allows enabling or disabling connection propagation for specific types of Private Service Connect endpoints.
Instance Attribute Summary collapse
-
#global_google_apis ⇒ ::Boolean
Optional.
-
#published_services_and_regional_google_apis ⇒ ::Boolean
Optional.
Instance Attribute Details
#global_google_apis ⇒ ::Boolean
Returns Optional. Controls whether Private Service Connect endpoints for global Google APIs should be propagated. The default value is false.
117 118 119 120 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 117 class ExportPscConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#published_services_and_regional_google_apis ⇒ ::Boolean
Returns Optional. Controls whether Private Service Connect endpoints for regional ILBs and regional Google APIs should be propagated. Default value is true if export_psc is true. Otherwise, the default value is false.
117 118 119 120 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 117 class ExportPscConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |