Class: Google::Cloud::NetworkConnectivity::V1beta::LinkedRouterApplianceInstances
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::LinkedRouterApplianceInstances
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
A collection of router appliance instances. If you configure multiple router appliance instances to receive data from the same set of sites outside of Google Cloud, we recommend that you associate those instances with the same spoke.
Instance Attribute Summary collapse
-
#include_import_ranges ⇒ ::Array<::String>
Optional.
-
#instances ⇒ ::Array<::Google::Cloud::NetworkConnectivity::V1beta::RouterApplianceInstance>
The list of router appliance instances.
-
#site_to_site_data_transfer ⇒ ::Boolean
A value that controls whether site-to-site data transfer is enabled for these resources.
-
#vpc_network ⇒ ::String
readonly
Output only.
Instance Attribute Details
#include_import_ranges ⇒ ::Array<::String>
Returns Optional. Hub routes fully encompassed by include import ranges are included during import from hub.
1342 1343 1344 1345 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1342 class LinkedRouterApplianceInstances include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instances ⇒ ::Array<::Google::Cloud::NetworkConnectivity::V1beta::RouterApplianceInstance>
Returns The list of router appliance instances.
1342 1343 1344 1345 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1342 class LinkedRouterApplianceInstances include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#site_to_site_data_transfer ⇒ ::Boolean
Returns A value that controls whether site-to-site data transfer is enabled for these resources. Data transfer is available only in supported locations.
1342 1343 1344 1345 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1342 class LinkedRouterApplianceInstances include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#vpc_network ⇒ ::String (readonly)
Returns Output only. The VPC network where these router appliance instances are located.
1342 1343 1344 1345 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1342 class LinkedRouterApplianceInstances include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |