Class: Google::Cloud::NetworkConnectivity::V1beta::LinkedVpcNetwork
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::LinkedVpcNetwork
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
An existing VPC network.
Instance Attribute Summary collapse
-
#exclude_export_ranges ⇒ ::Array<::String>
Optional.
-
#include_export_ranges ⇒ ::Array<::String>
Optional.
-
#producer_vpc_spokes ⇒ ::Array<::String>
readonly
Output only.
-
#proposed_exclude_export_ranges ⇒ ::Array<::String>
readonly
Output only.
-
#proposed_include_export_ranges ⇒ ::Array<::String>
readonly
Output only.
-
#uri ⇒ ::String
Required.
Instance Attribute Details
#exclude_export_ranges ⇒ ::Array<::String>
Returns Optional. IP ranges encompassing the subnets to be excluded from peering.
1374 1375 1376 1377 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1374 class LinkedVpcNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#include_export_ranges ⇒ ::Array<::String>
Returns Optional. IP ranges allowed to be included from peering.
1374 1375 1376 1377 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1374 class LinkedVpcNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#producer_vpc_spokes ⇒ ::Array<::String> (readonly)
Returns Output only. The list of Producer VPC spokes that this VPC spoke is a service consumer VPC spoke for. These producer VPCs are connected through VPC peering to this spoke's backing VPC network. Because they are directly connected through VPC peering, NCC export filters do not apply between the service consumer VPC spoke and any of its producer VPC spokes. This VPC spoke cannot be deleted as long as any of these producer VPC spokes are connected to the NCC Hub.
1374 1375 1376 1377 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1374 class LinkedVpcNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#proposed_exclude_export_ranges ⇒ ::Array<::String> (readonly)
Returns Output only. The proposed exclude export IP ranges waiting for hub administrator's approval.
1374 1375 1376 1377 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1374 class LinkedVpcNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#proposed_include_export_ranges ⇒ ::Array<::String> (readonly)
Returns Output only. The proposed include export IP ranges waiting for hub administrator's approval.
1374 1375 1376 1377 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1374 class LinkedVpcNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#uri ⇒ ::String
Returns Required. The URI of the VPC network resource.
1374 1375 1376 1377 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1374 class LinkedVpcNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |