Class: Google::Cloud::NetworkConnectivity::V1beta::ListGatewayAdvertisedRoutesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::ListGatewayAdvertisedRoutesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
The request for HubService.ListGatewayAdvertisedRoutes.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
An expression that filters the list of results.
-
#order_by ⇒ ::String
Sort the results by a certain order.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns An expression that filters the list of results.
1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1564 class ListGatewayAdvertisedRoutesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Sort the results by a certain order.
1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1564 class ListGatewayAdvertisedRoutesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of results per page that should be returned.
1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1564 class ListGatewayAdvertisedRoutesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous
ListGatewayAdvertisedRoutes call. Provide this to retrieve the subsequent
page.
When paginating, all other parameters provided to
ListGatewayAdvertisedRoutes must match the call that provided the page
token.
1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1564 class ListGatewayAdvertisedRoutesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource's name.
1564 1565 1566 1567 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1564 class ListGatewayAdvertisedRoutesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |