Class: Google::Cloud::NetworkConnectivity::V1beta::NextHopSpoke
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::NextHopSpoke
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
A route next hop that leads to a spoke resource.
Instance Attribute Summary collapse
-
#site_to_site_data_transfer ⇒ ::Boolean
Indicates whether site-to-site data transfer is allowed for this spoke resource.
-
#uri ⇒ ::String
The URI of the spoke resource.
Instance Attribute Details
#site_to_site_data_transfer ⇒ ::Boolean
Returns Indicates whether site-to-site data transfer is allowed for this spoke resource. Data transfer is available only in supported locations. Whether this route is accessible to other hybrid spokes with site-to-site data transfer enabled. If this is false, the route is only accessible to VPC spokes of the connected Hub.
1783 1784 1785 1786 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1783 class NextHopSpoke include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#uri ⇒ ::String
Returns The URI of the spoke resource.
1783 1784 1785 1786 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1783 class NextHopSpoke include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |