Module: Google::Cloud::NetworkConnectivity::V1beta::PresetTopology
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
The list of available preset topologies.
Constant Summary collapse
- PRESET_TOPOLOGY_UNSPECIFIED =
Preset topology is unspecified. When policy_mode = PRESET, it defaults to MESH.
0- MESH =
Mesh topology is implemented. Group
defaultis automatically created. All spokes in the hub are added to groupdefault. 2- STAR =
Star topology is implemented. Two groups,
centerandedge, are automatically created along with hub creation. Spokes have to join one of the groups during creation. 3- HYBRID_INSPECTION =
Hybrid inspection has 4 groups ('non-prod', 'prod', 'services', and 'untrusted') that are automatically created along with hub creation.
4