Class: Google::Cloud::NetworkConnectivity::V1beta::PscPropagationStatus
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1beta::PscPropagationStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb
Overview
The status of one or more propagated Private Service Connect connections in a hub.
Defined Under Namespace
Modules: Code
Instance Attribute Summary collapse
-
#code ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::PscPropagationStatus::Code
The propagation status.
-
#message ⇒ ::String
The human-readable summary of the Private Service Connect connection propagation status.
-
#source_forwarding_rule ⇒ ::String
The name of the forwarding rule exported to the hub.
-
#source_group ⇒ ::String
The name of the group that the source spoke belongs to.
-
#source_spoke ⇒ ::String
The name of the spoke that the source forwarding rule belongs to.
-
#target_group ⇒ ::String
The name of the group that the target spoke belongs to.
-
#target_spoke ⇒ ::String
The name of the spoke that the source forwarding rule propagates to.
Instance Attribute Details
#code ⇒ ::Google::Cloud::NetworkConnectivity::V1beta::PscPropagationStatus::Code
Returns The propagation status.
800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 800 class PscPropagationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Code enum represents the state of the Private Service Connect # propagation. module Code # The code is unspecified. CODE_UNSPECIFIED = 0 # The propagated Private Service Connect connection is ready. READY = 1 # The Private Service Connect connection is propagating. This is a # transient state. PROPAGATING = 2 # The Private Service Connect connection propagation failed because the VPC # network or the project of the target spoke has exceeded the connection # limit set by the producer. ERROR_PRODUCER_PROPAGATED_CONNECTION_LIMIT_EXCEEDED = 3 # The Private Service Connect connection propagation failed because the NAT # IP subnet space has been exhausted. It is equivalent to the `Needs # attention` status of the Private Service Connect connection. See # https://cloud.google.com/vpc/docs/about-accessing-vpc-hosted-services-endpoints#connection-statuses. ERROR_PRODUCER_NAT_IP_SPACE_EXHAUSTED = 4 # The Private Service Connect connection propagation failed because the # `PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK` quota in the # producer VPC network has been exceeded. ERROR_PRODUCER_QUOTA_EXCEEDED = 5 # The Private Service Connect connection propagation failed because the # `PSC_PROPAGATED_CONNECTIONS_PER_VPC_NETWORK` quota in the consumer # VPC network has been exceeded. ERROR_CONSUMER_QUOTA_EXCEEDED = 6 end end |
#message ⇒ ::String
Returns The human-readable summary of the Private Service Connect connection propagation status.
800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 800 class PscPropagationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Code enum represents the state of the Private Service Connect # propagation. module Code # The code is unspecified. CODE_UNSPECIFIED = 0 # The propagated Private Service Connect connection is ready. READY = 1 # The Private Service Connect connection is propagating. This is a # transient state. PROPAGATING = 2 # The Private Service Connect connection propagation failed because the VPC # network or the project of the target spoke has exceeded the connection # limit set by the producer. ERROR_PRODUCER_PROPAGATED_CONNECTION_LIMIT_EXCEEDED = 3 # The Private Service Connect connection propagation failed because the NAT # IP subnet space has been exhausted. It is equivalent to the `Needs # attention` status of the Private Service Connect connection. See # https://cloud.google.com/vpc/docs/about-accessing-vpc-hosted-services-endpoints#connection-statuses. ERROR_PRODUCER_NAT_IP_SPACE_EXHAUSTED = 4 # The Private Service Connect connection propagation failed because the # `PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK` quota in the # producer VPC network has been exceeded. ERROR_PRODUCER_QUOTA_EXCEEDED = 5 # The Private Service Connect connection propagation failed because the # `PSC_PROPAGATED_CONNECTIONS_PER_VPC_NETWORK` quota in the consumer # VPC network has been exceeded. ERROR_CONSUMER_QUOTA_EXCEEDED = 6 end end |
#source_forwarding_rule ⇒ ::String
Returns The name of the forwarding rule exported to the hub.
800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 800 class PscPropagationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Code enum represents the state of the Private Service Connect # propagation. module Code # The code is unspecified. CODE_UNSPECIFIED = 0 # The propagated Private Service Connect connection is ready. READY = 1 # The Private Service Connect connection is propagating. This is a # transient state. PROPAGATING = 2 # The Private Service Connect connection propagation failed because the VPC # network or the project of the target spoke has exceeded the connection # limit set by the producer. ERROR_PRODUCER_PROPAGATED_CONNECTION_LIMIT_EXCEEDED = 3 # The Private Service Connect connection propagation failed because the NAT # IP subnet space has been exhausted. It is equivalent to the `Needs # attention` status of the Private Service Connect connection. See # https://cloud.google.com/vpc/docs/about-accessing-vpc-hosted-services-endpoints#connection-statuses. ERROR_PRODUCER_NAT_IP_SPACE_EXHAUSTED = 4 # The Private Service Connect connection propagation failed because the # `PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK` quota in the # producer VPC network has been exceeded. ERROR_PRODUCER_QUOTA_EXCEEDED = 5 # The Private Service Connect connection propagation failed because the # `PSC_PROPAGATED_CONNECTIONS_PER_VPC_NETWORK` quota in the consumer # VPC network has been exceeded. ERROR_CONSUMER_QUOTA_EXCEEDED = 6 end end |
#source_group ⇒ ::String
Returns The name of the group that the source spoke belongs to.
800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 800 class PscPropagationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Code enum represents the state of the Private Service Connect # propagation. module Code # The code is unspecified. CODE_UNSPECIFIED = 0 # The propagated Private Service Connect connection is ready. READY = 1 # The Private Service Connect connection is propagating. This is a # transient state. PROPAGATING = 2 # The Private Service Connect connection propagation failed because the VPC # network or the project of the target spoke has exceeded the connection # limit set by the producer. ERROR_PRODUCER_PROPAGATED_CONNECTION_LIMIT_EXCEEDED = 3 # The Private Service Connect connection propagation failed because the NAT # IP subnet space has been exhausted. It is equivalent to the `Needs # attention` status of the Private Service Connect connection. See # https://cloud.google.com/vpc/docs/about-accessing-vpc-hosted-services-endpoints#connection-statuses. ERROR_PRODUCER_NAT_IP_SPACE_EXHAUSTED = 4 # The Private Service Connect connection propagation failed because the # `PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK` quota in the # producer VPC network has been exceeded. ERROR_PRODUCER_QUOTA_EXCEEDED = 5 # The Private Service Connect connection propagation failed because the # `PSC_PROPAGATED_CONNECTIONS_PER_VPC_NETWORK` quota in the consumer # VPC network has been exceeded. ERROR_CONSUMER_QUOTA_EXCEEDED = 6 end end |
#source_spoke ⇒ ::String
Returns The name of the spoke that the source forwarding rule belongs to.
800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 800 class PscPropagationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Code enum represents the state of the Private Service Connect # propagation. module Code # The code is unspecified. CODE_UNSPECIFIED = 0 # The propagated Private Service Connect connection is ready. READY = 1 # The Private Service Connect connection is propagating. This is a # transient state. PROPAGATING = 2 # The Private Service Connect connection propagation failed because the VPC # network or the project of the target spoke has exceeded the connection # limit set by the producer. ERROR_PRODUCER_PROPAGATED_CONNECTION_LIMIT_EXCEEDED = 3 # The Private Service Connect connection propagation failed because the NAT # IP subnet space has been exhausted. It is equivalent to the `Needs # attention` status of the Private Service Connect connection. See # https://cloud.google.com/vpc/docs/about-accessing-vpc-hosted-services-endpoints#connection-statuses. ERROR_PRODUCER_NAT_IP_SPACE_EXHAUSTED = 4 # The Private Service Connect connection propagation failed because the # `PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK` quota in the # producer VPC network has been exceeded. ERROR_PRODUCER_QUOTA_EXCEEDED = 5 # The Private Service Connect connection propagation failed because the # `PSC_PROPAGATED_CONNECTIONS_PER_VPC_NETWORK` quota in the consumer # VPC network has been exceeded. ERROR_CONSUMER_QUOTA_EXCEEDED = 6 end end |
#target_group ⇒ ::String
Returns The name of the group that the target spoke belongs to.
800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 800 class PscPropagationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Code enum represents the state of the Private Service Connect # propagation. module Code # The code is unspecified. CODE_UNSPECIFIED = 0 # The propagated Private Service Connect connection is ready. READY = 1 # The Private Service Connect connection is propagating. This is a # transient state. PROPAGATING = 2 # The Private Service Connect connection propagation failed because the VPC # network or the project of the target spoke has exceeded the connection # limit set by the producer. ERROR_PRODUCER_PROPAGATED_CONNECTION_LIMIT_EXCEEDED = 3 # The Private Service Connect connection propagation failed because the NAT # IP subnet space has been exhausted. It is equivalent to the `Needs # attention` status of the Private Service Connect connection. See # https://cloud.google.com/vpc/docs/about-accessing-vpc-hosted-services-endpoints#connection-statuses. ERROR_PRODUCER_NAT_IP_SPACE_EXHAUSTED = 4 # The Private Service Connect connection propagation failed because the # `PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK` quota in the # producer VPC network has been exceeded. ERROR_PRODUCER_QUOTA_EXCEEDED = 5 # The Private Service Connect connection propagation failed because the # `PSC_PROPAGATED_CONNECTIONS_PER_VPC_NETWORK` quota in the consumer # VPC network has been exceeded. ERROR_CONSUMER_QUOTA_EXCEEDED = 6 end end |
#target_spoke ⇒ ::String
Returns The name of the spoke that the source forwarding rule propagates to.
800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 |
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 800 class PscPropagationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Code enum represents the state of the Private Service Connect # propagation. module Code # The code is unspecified. CODE_UNSPECIFIED = 0 # The propagated Private Service Connect connection is ready. READY = 1 # The Private Service Connect connection is propagating. This is a # transient state. PROPAGATING = 2 # The Private Service Connect connection propagation failed because the VPC # network or the project of the target spoke has exceeded the connection # limit set by the producer. ERROR_PRODUCER_PROPAGATED_CONNECTION_LIMIT_EXCEEDED = 3 # The Private Service Connect connection propagation failed because the NAT # IP subnet space has been exhausted. It is equivalent to the `Needs # attention` status of the Private Service Connect connection. See # https://cloud.google.com/vpc/docs/about-accessing-vpc-hosted-services-endpoints#connection-statuses. ERROR_PRODUCER_NAT_IP_SPACE_EXHAUSTED = 4 # The Private Service Connect connection propagation failed because the # `PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK` quota in the # producer VPC network has been exceeded. ERROR_PRODUCER_QUOTA_EXCEEDED = 5 # The Private Service Connect connection propagation failed because the # `PSC_PROPAGATED_CONNECTIONS_PER_VPC_NETWORK` quota in the consumer # VPC network has been exceeded. ERROR_CONSUMER_QUOTA_EXCEEDED = 6 end end |