Module: Google::Cloud::NetworkConnectivity::V1beta::RemoteTransportProfile::ServiceLevelAvailability
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1beta/transport_manager.rb
Overview
Availability class options.
Constant Summary collapse
- SERVICE_LEVEL_AVAILABILITY_UNSPECIFIED =
Unspecified service level availability.
0- HIGH =
This represents a 99.9% service level on the availability of the configured connectivity.
1- MAXIMUM =
This represents a 99.99% service level on the availability of the configured connectivity.
2