Class: Google::Cloud::NetworkConnectivity::V1beta::SpokeSummary

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb

Overview

Summarizes information about the spokes associated with a hub. The summary includes a count of spokes according to type and according to state. If any spokes are inactive, the summary also lists the reasons they are inactive, including a count for each reason.

Defined Under Namespace

Classes: SpokeStateCount, SpokeStateReasonCount, SpokeTypeCount

Instance Attribute Summary collapse

Instance Attribute Details

#spoke_state_counts::Array<::Google::Cloud::NetworkConnectivity::V1beta::SpokeSummary::SpokeStateCount> (readonly)

Returns Output only. Counts the number of spokes that are in each state and associated with a given hub.

Returns:



1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1805

class SpokeSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The number of spokes of a given type that are associated
  # with a specific hub. The type indicates what kind of
  # resource is associated with the spoke.
  # @!attribute [r] spoke_type
  #   @return [::Google::Cloud::NetworkConnectivity::V1beta::SpokeType]
  #     Output only. The type of the spokes.
  # @!attribute [r] count
  #   @return [::Integer]
  #     Output only. The total number of spokes of this type that are
  #     associated with the hub.
  class SpokeTypeCount
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The number of spokes that are in a particular state
  # and associated with a given hub.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkConnectivity::V1beta::State]
  #     Output only. The state of the spokes.
  # @!attribute [r] count
  #   @return [::Integer]
  #     Output only. The total number of spokes that are in this state
  #     and associated with a given hub.
  class SpokeStateCount
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The number of spokes in the hub that are inactive for this reason.
  # @!attribute [r] state_reason_code
  #   @return [::Google::Cloud::NetworkConnectivity::V1beta::Spoke::StateReason::Code]
  #     Output only. The reason that a spoke is inactive.
  # @!attribute [r] count
  #   @return [::Integer]
  #     Output only. The total number of spokes that are inactive for a
  #     particular reason and associated with a given hub.
  class SpokeStateReasonCount
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#spoke_state_reason_counts::Array<::Google::Cloud::NetworkConnectivity::V1beta::SpokeSummary::SpokeStateReasonCount> (readonly)

Returns Output only. Counts the number of spokes that are inactive for each possible reason and associated with a given hub.

Returns:



1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1805

class SpokeSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The number of spokes of a given type that are associated
  # with a specific hub. The type indicates what kind of
  # resource is associated with the spoke.
  # @!attribute [r] spoke_type
  #   @return [::Google::Cloud::NetworkConnectivity::V1beta::SpokeType]
  #     Output only. The type of the spokes.
  # @!attribute [r] count
  #   @return [::Integer]
  #     Output only. The total number of spokes of this type that are
  #     associated with the hub.
  class SpokeTypeCount
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The number of spokes that are in a particular state
  # and associated with a given hub.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkConnectivity::V1beta::State]
  #     Output only. The state of the spokes.
  # @!attribute [r] count
  #   @return [::Integer]
  #     Output only. The total number of spokes that are in this state
  #     and associated with a given hub.
  class SpokeStateCount
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The number of spokes in the hub that are inactive for this reason.
  # @!attribute [r] state_reason_code
  #   @return [::Google::Cloud::NetworkConnectivity::V1beta::Spoke::StateReason::Code]
  #     Output only. The reason that a spoke is inactive.
  # @!attribute [r] count
  #   @return [::Integer]
  #     Output only. The total number of spokes that are inactive for a
  #     particular reason and associated with a given hub.
  class SpokeStateReasonCount
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#spoke_type_counts::Array<::Google::Cloud::NetworkConnectivity::V1beta::SpokeSummary::SpokeTypeCount> (readonly)

Returns Output only. Counts the number of spokes of each type that are associated with a specific hub.

Returns:



1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
# File 'proto_docs/google/cloud/networkconnectivity/v1beta/hub.rb', line 1805

class SpokeSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The number of spokes of a given type that are associated
  # with a specific hub. The type indicates what kind of
  # resource is associated with the spoke.
  # @!attribute [r] spoke_type
  #   @return [::Google::Cloud::NetworkConnectivity::V1beta::SpokeType]
  #     Output only. The type of the spokes.
  # @!attribute [r] count
  #   @return [::Integer]
  #     Output only. The total number of spokes of this type that are
  #     associated with the hub.
  class SpokeTypeCount
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The number of spokes that are in a particular state
  # and associated with a given hub.
  # @!attribute [r] state
  #   @return [::Google::Cloud::NetworkConnectivity::V1beta::State]
  #     Output only. The state of the spokes.
  # @!attribute [r] count
  #   @return [::Integer]
  #     Output only. The total number of spokes that are in this state
  #     and associated with a given hub.
  class SpokeStateCount
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The number of spokes in the hub that are inactive for this reason.
  # @!attribute [r] state_reason_code
  #   @return [::Google::Cloud::NetworkConnectivity::V1beta::Spoke::StateReason::Code]
  #     Output only. The reason that a spoke is inactive.
  # @!attribute [r] count
  #   @return [::Integer]
  #     Output only. The total number of spokes that are inactive for a
  #     particular reason and associated with a given hub.
  class SpokeStateReasonCount
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end